@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,6 +25,7 @@
 #include "core/memory/policy/NeverDump.hpp"
 #include "core/memory/stream/in/Buffer.hpp"
 #include "core/memory/stream/in/Raw.hpp"
+
 #include <core/com/Signal.hxx>
 #include <core/LazyInstantiator.hpp>
 #include <core/thread/Worker.hpp>
@@ -339,7 +340,7 @@ struct AutoUnlock
         {
             m_manager->unlockBuffer(m_bufferPtr);
         }
-        catch(std::exception& e)
+        catch([[maybe_unused]] const std::exception& e)
         {
             SIGHT_ASSERT("Unlock Failed" << e.what(), 0);
         }
@@ -480,9 +481,9 @@ bool BufferManager::restoreBuffer(
         SizeType size  = std::min(allocSize, info.size);
         bool notFailed = false;
         {
-            SPTR(std::istream) isptr = (*info.istreamFactory)();
-            std::istream& is = *isptr;
-            SizeType read    = is.read(charBuf, size).gcount();
+            SPTR(std::istream) stream = (*info.istreamFactory)();
+            std::istream& is    = *stream;
+            const SizeType read = static_cast<SizeType>(is.read(charBuf, static_cast<std::streamsize>(size)).gcount());
 
             SIGHT_THROW_IF(" Bad file size, expected: " << size << ", was: " << read, size - read != 0);
             notFailed = !is.fail();
@@ -538,7 +539,7 @@ bool BufferManager::writeBufferImpl(
     std::ofstream fs(path, std::ios::binary | std::ios::trunc);
     SIGHT_THROW_IF("Memory management : Unable to open " << path, !fs.good());
     const char* charBuf = static_cast<const char*>(buffer);
-    fs.write(charBuf, size);
+    fs.write(charBuf, static_cast<std::streamsize>(size));
     fs.close();
     return !fs.bad();
 }
@@ -566,11 +567,11 @@ bool BufferManager::readBufferImpl(BufferManager::BufferType buffer, SizeType si
 
     SIGHT_THROW_IF(
         path << ": Bad file size, expected: " << size << ", was: " << fileSize,
-        size - fileSize != 0
+        size - static_cast<SizeType>(fileSize) != 0
     );
 
     char* charBuf = static_cast<char*>(buffer);
-    fs.read(charBuf, size);
+    fs.read(charBuf, static_cast<std::streamsize>(size));
 
     fs.close();
     return !fs.bad();
