@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -36,6 +36,7 @@ CPPUNIT_TEST_SUITE(WorkerTest);
 CPPUNIT_TEST(basicTest);
 // Disable timerTest because it fails randomly on a busy computer (see #253)
 //CPPUNIT_TEST( timerTest );
+CPPUNIT_TEST(registryTest);
 CPPUNIT_TEST_SUITE_END();
 
 public:
@@ -46,6 +47,7 @@ public:
 
     void basicTest();
     void timerTest();
+    void registryTest();
 };
 
 } //namespace ut
