@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,7 +24,7 @@
 
 #include "data/Array.hpp"
 #include "data/factory/new.hpp"
-#include "data/iterator/ImageIterator.hpp"
+#include "data/iterator.hpp"
 #include "data/Object.hpp"
 
 #include <core/com/Signal.hpp>
@@ -32,13 +32,13 @@
 #include <core/memory/IBuffered.hpp>
 #include <core/tools/Type.hpp>
 
+#include <data/iterator.hpp>
+
 #include <boost/shared_array.hpp>
 
 #include <filesystem>
 #include <vector>
 
-SIGHT_DECLARE_DATA_REFLECTION((sight) (data) (Image));
-
 namespace sight::data
 {
 
@@ -53,7 +53,7 @@ class PointList;
  * The buffer type is defined by core::tools::Type that provides the basic types ([u]int8, [u]int16, [u]int32, [u]int64,
  * float and double).
  *
- * The image size is a 3D size_t array but the third dimension can be 0 for a 2D image.
+ * The image size is a 3D std::size_t array but the third dimension can be 0 for a 2D image.
  *
  * The image PixelFormat represents the buffer organization in components (GRAY_SCALE: 1 component, RGB and BGR: 3
  * components, RGBA and BGRA: 4 components).
@@ -65,14 +65,8 @@ class PointList;
  * The image buffer is allocated using the resize() method.
  * You can get the allocated size using getSizeInBytes() and getAllocatedSizeInBytes().
  *
- * @warning The allocated size can be different from the image size: it can happen if you called setSize() without
- * calling resize(). It may be useful when you don't want to reallocate the image too often, but you need to be sure to
- * allocate enough memory.
- *
- * To resize the image, you must define the Type ([u]int[8|16|32|64], double, float), the size and the pixel
- * format of the buffer. You can use setSize2(const Size& size), setType(core::tools::Type type) and
- * setPixelFormat(PixelFormat format) or directly call
- * resize(const Size& size, const core::tools::Type& type, PixelFormat format).
+ * To resize the image, you must pass the Type ([u]int[8|16|32|64], double, float), the size and the pixel
+ * format of the buffer when calling resize(const Size& size, const core::tools::Type& type, PixelFormat format).
  *
  * @section Access Buffer access
  *
@@ -92,20 +86,20 @@ class PointList;
     // 3D image of std::int16_t
 
     // prevent the buffer to be dumped on the disk
-    const auto dumpLock = image->lock();
+    const auto dumpLock = image->dump_lock();
 
     // retrieve the value at index (x, y, z)
     value = image->at<std::int16_t>(x, y, z);
 
     // or you can compute the index like
-    const auto size = image->getSize2();
-    const size_t index = x + y*size[0] + z*size[0]*size[1];
+    const auto size = image->getSize();
+    const std::size_t index = x + y*size[0] + z*size[0]*size[1];
     value = image->at<std::int16_t>(index);
    @endcode
  *
- * @subsection Iterators Iterators
+ * @subsection iterators iterators
  *
- * To parse the buffer from beginning to end, the iterator can be used (data::iterator::ImageIteratorBase).
+ * To parse the buffer from beginning to end, the iterator can be used (iterator::ImageiteratorBase).
  *
  * The iteration depends on the given format. The format can be the buffer type ([u]int[8|16|32|64], double, float), but
  * can also be a simple struct like:
@@ -121,15 +115,15 @@ class PointList;
  *
  * This struct allows to parse the image as an RGBA buffer (RGBARGBARGBA....).
  *
- * To get an iterator on the image, use begin<FORMAT>() and end<FORMAT>() methods.
+ * To get an iterator on the image, use begin<T>() and end<T>() methods.
  *
  * @warning The iterator does not assert that the image type is the same as the given format. It only asserts (in debug)
  * that the iterator does not iterate outside of the buffer bounds).
  *
  * \b Example :
  * @code{.cpp}
-    data::Image::sptr img = data::Image::New();
-    img->resize(1920, 1080, 1, core::tools::Type::s_UINT8, data::Image::PixelFormat::RGBA);
+    Image::sptr img = Image::New();
+    img->resize(1920, 1080, 1, core::tools::Type::s_UINT8, Image::PixelFormat::RGBA);
     auto iter    = img->begin<Color>();
     const auto iterEnd = img->end<Color>();
 
@@ -148,15 +142,15 @@ class PointList;
  * @note If you need to know (x, y, z) indices, you can parse the array looping from the last dimension to the first,
  * like:
  * @code{.cpp}
-    const auto size = image->getSize2();
+    const auto size = image->getSize();
 
     auto iter    = image->begin<Color>();
 
-    for (size_t z=0 ; z<size[2] ; ++z)
+    for (std::size_t z=0 ; z<size[2] ; ++z)
     {
-        for (size_t y=0 ; y<size[1] ; ++y)
+        for (std::size_t y=0 ; y<size[1] ; ++y)
         {
-            for (size_t x=0 ; x<size[0] ; ++x)
+            for (std::size_t x=0 ; x<size[0] ; ++x)
             {
                 // do something with x and y ....
 
@@ -174,17 +168,16 @@ class PointList;
    @endcode
  */
 /* *INDENT-ON* */
-class DATA_CLASS_API Image : public data::Object,
+class DATA_CLASS_API Image : public Object,
                              public core::memory::IBuffered
 {
 public:
 
-    SIGHT_DECLARE_CLASS(Image, data::Object, data::factory::New<Image>);
+    SIGHT_DECLARE_CLASS(Image, Object, factory::New<Image>);
     SIGHT_ALLOW_SHARED_FROM_THIS()
-    SIGHT_MAKE_FRIEND_REFLECTION((sight) (data) (Image))
 
     /// Image size
-    typedef std::array<size_t, 3> Size;
+    typedef std::array<std::size_t, 3> Size;
     /// Image origin
     typedef std::array<double, 3> Origin;
     /// Image spacing
@@ -192,7 +185,7 @@ public:
 
     typedef Size::value_type IndexType;
     typedef std::uint8_t BufferType;
-    typedef ::boost::shared_array<BufferType> SharedArray;
+    typedef boost::shared_array<BufferType> SharedArray;
 
     /// Image format
     enum PixelFormat
@@ -202,14 +195,16 @@ public:
         RGBA,          ///< Image with 4 component RGBA.
         BGR,           ///< Image with 3 component BGR.
         BGRA,          ///< Image with 4 component BGRA.
-        GRAY_SCALE     ///< Image with 1 component.
+        GRAY_SCALE,    ///< Image with 1 component.
+        RG,            ///< Image with 2 components RG.
+        _SIZE
     };
 
     /**
      * @brief Constructor
      * @param key Private construction key
      */
-    DATA_API Image(data::Object::Key key);
+    DATA_API Image(Object::Key key);
 
     /**
      * @brief Destructor
@@ -219,54 +214,29 @@ public:
     /// Defines shallow copy
     DATA_API void shallowCopy(const Object::csptr& _source) override;
 
-    /// Defines deep copy
-    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
-
     /// @brief get image information from source. Informations are spacing,origin,size ... expect Fields
     DATA_API void copyInformation(Image::csptr _source);
 
-    /**
-     * @brief Get image spacing
-     * @todo Rename to getSpacing when the deprecated API is removed
-     */
-    const Spacing& getSpacing2() const;
-    /**
-     * @brief Set image spacing
-     * @todo Rename to setSpacing when the deprecated API is removed
-     */
-    void setSpacing2(const Spacing& spacing);
+    /// Get image spacing
+    const Spacing& getSpacing() const;
+    /// Set image spacing
+    void setSpacing(const Spacing& spacing);
 
-    /**
-     * @brief Get image origin
-     * @todo Rename to getOrigin when the deprecated API is removed
-     */
-    const Origin& getOrigin2() const;
-    /**
-     * @brief Set image origin
-     * @todo Rename to setOrigin when the deprecated API is removed
-     */
-    void setOrigin2(const Origin& origin);
+    /// Get image origin
+    const Origin& getOrigin() const;
+    /// Set image origin
+    void setOrigin(const Origin& origin);
 
-    /**
-     * @brief Get image size
-     * @todo Rename to getSize when the deprecated API is removed
-     */
-    const Size& getSize2() const;
-    /**
-     * @brief Set image size
-     * @warning This method does not resize the buffer. You must call resize for that.
-     * @todo Rename to setSize when the deprecated API is removed
-     */
-    void setSize2(const Size& size);
+    /// Get image size
+    const Size& getSize() const;
 
     /// Number of dimensions of the image (3 for 3D image)
-    DATA_API size_t getNumberOfDimensions() const;
+    DATA_API std::size_t numDimensions() const;
 
     /** @{
      *  @brief Get/set preferred window center
      */
     double getWindowCenter() const;
-
     void setWindowCenter(double val);
     /// @}
 
@@ -278,46 +248,39 @@ public:
     /// @}
 
     /// Get the number of elements (ie: size[0]*size[1]*size[2]*nbComponents)
-    DATA_API size_t getNumElements() const;
+    DATA_API std::size_t numElements() const;
 
-    /** @{
-     *  @brief Get/set preferred window center
-     */
-    size_t getNumberOfComponents() const;
+    /// Get the number of components of an image pixel
+    std::size_t numComponents() const;
 
-    void setNumberOfComponents(size_t val);
-    /// @}
-
-    /** @{
-     * @brief get/set image type
-     * @warning This method does not resize the buffer with the new type. You must call resize for that.
-     */
-    DATA_API void setType(core::tools::Type type);
-    DATA_API void setType(const std::string& type);
+    /// Get image type
     DATA_API core::tools::Type getType() const;
-    /// @}
+
+    /// Get pixel format
+    PixelFormat getPixelFormat() const;
 
     /**
        @{
      * @brief Resize the image and allocate the memory if needed.
      *
-     * If the data array owns its buffer, these methods will always work (until it remain free memory)
+     * @param size array of size in each direction (x,y,z)
+     * @param type type of a single pixel component value
+     * @param format specify the ordering and the meaning of a pixel components
+     *
+     * If the data array owns its buffer, this method will always work (until it remain free memory)
      * Otherwise an exception is thrown :
      *  - if m_dataArray does not own it buffer and image's size and type combination do not match anymore array's one
      *  - if there is no memory left
      *
      * @return Allocated size in bytes
      */
-    DATA_API size_t resize();
-
-    DATA_API size_t resize(IndexType x, IndexType y, IndexType z, const core::tools::Type& type, PixelFormat format);
-    DATA_API size_t resize(const Size& size, const core::tools::Type& type, PixelFormat format);
+    DATA_API std::size_t resize(const Size& size, const core::tools::Type& type, PixelFormat format);
     /// @}
 
     /// @brief return image size in bytes
-    DATA_API size_t getSizeInBytes() const;
+    DATA_API std::size_t getSizeInBytes() const;
     /// @brief return allocated image size in bytes
-    DATA_API size_t getAllocatedSizeInBytes() const;
+    DATA_API std::size_t getAllocatedSizeInBytes() const;
 
     /**
      * @name Signals
@@ -328,11 +291,11 @@ public:
     DATA_API static const core::com::Signals::SignalKeyType s_BUFFER_MODIFIED_SIG;
 
     /// Type of signal when a landmark is added
-    typedef core::com::Signal<void (SPTR(data::Point))> LandmarkAddedSignalType;
+    typedef core::com::Signal<void (SPTR(Point))> LandmarkAddedSignalType;
     DATA_API static const core::com::Signals::SignalKeyType s_LANDMARK_ADDED_SIG;
 
     /// Type of signal when a landmark is removed
-    typedef core::com::Signal<void (SPTR(data::Point))> LandmarkRemovedSignalType;
+    typedef core::com::Signal<void (SPTR(Point))> LandmarkRemovedSignalType;
     DATA_API static const core::com::Signals::SignalKeyType s_LANDMARK_REMOVED_SIG;
 
     /// Type of signal when a distance is added
@@ -344,11 +307,11 @@ public:
     DATA_API static const core::com::Signals::SignalKeyType s_DISTANCE_DISPLAYED_SIG;
 
     /// Type of signal when a distance is added
-    typedef core::com::Signal<void (SPTR(data::PointList))> DistanceAddedSignalType;
+    typedef core::com::Signal<void (SPTR(PointList))> DistanceAddedSignalType;
     DATA_API static const core::com::Signals::SignalKeyType s_DISTANCE_ADDED_SIG;
 
     /// Type of signal when a distance is removed
-    typedef core::com::Signal<void (CSPTR(data::PointList))> DistanceRemovedSignalType;
+    typedef core::com::Signal<void (CSPTR(PointList))> DistanceRemovedSignalType;
     DATA_API static const core::com::Signals::SignalKeyType s_DISTANCE_REMOVED_SIG;
 
     /// Type of signal when slice index is modified (axial index, frontal index, sagittal index)
@@ -376,11 +339,10 @@ public:
      * @{
      */
     /// Image iterator
-    template<typename FORMAT>
-    using Iterator = iterator::ImageIteratorBase<FORMAT, false>;
-    template<typename FORMAT>
-    /// Image const iterator
-    using ConstIterator = iterator::ImageIteratorBase<FORMAT, true>;
+    template<typename T>
+    using iterator = array_iterator<T>;
+    template<typename T>
+    using const_iterator = array_iterator<const T>;
     /// @}
 
     /**
@@ -397,14 +359,14 @@ public:
             std::uint8_t a;
         };
         @endcode
-     * @see data::iterator::RGBA
+     * @see iterator::rgba
      *
      * Example:
      * @code{.cpp}
-        data::Image::sptr img = data::Image::New();
-        img->resize(1920, 1080, 0, core::tools::Type::s_UINT8, data::Image::PixelFormat::RGBA);
-        data::Image::Iterator< Color > iter    = img->begin< Color >();
-        const data::Image::Iterator< Color > iterEnd = img->end< Color >();
+        Image::sptr img = Image::New();
+        img->resize(1920, 1080, 0, core::tools::Type::s_UINT8, Image::PixelFormat::RGBA);
+        Image::iterator< Color > iter    = img->begin< Color >();
+        const Image::iterator< Color > iterEnd = img->end< Color >();
 
         for (; iter != iterEnd; ++iter)
         {
@@ -417,37 +379,49 @@ public:
      *
      * @warning The iterator does not assert that the buffer type is the same as the given format. It only asserts
      * (in debug) that the iterator does not iterate outside of the buffer bounds).
-     * @note These functions lock the buffer for dump (see lock()).
      * @{
      */
-    template<typename FORMAT>
-    Iterator<FORMAT> begin();
-    template<typename FORMAT>
-    Iterator<FORMAT> end();
-    template<typename FORMAT>
-    ConstIterator<FORMAT> begin() const;
-    template<typename FORMAT>
-    ConstIterator<FORMAT> end() const;
+    template<typename T>
+    iterator<T> begin();
+    template<typename T>
+    iterator<T> end();
+    template<typename T>
+    const_iterator<T> begin() const;
+    template<typename T>
+    const_iterator<T> end() const;
+    template<typename T>
+    const_iterator<T> cbegin() const;
+    template<typename T>
+    const_iterator<T> cend() const;
     /// @}
+
+    /**
+     * @brief Returns a range of begin/end iterators, especially useful to be used in "for range loops".
+     * @{
+     */
+    template<typename T>
+    auto range();
+    template<typename T>
+    auto crange() const;
+    /// @}
+
     /**
      * @brief Returns the begin/end iterators to the array buffer, cast to char
      *
      * Iterate through all the element of the buffer.
-     *
-     * @note These functions lock the buffer
      * @{
      */
-    DATA_API Iterator<char> begin();
-    DATA_API Iterator<char> end();
-    DATA_API ConstIterator<char> begin() const;
-    DATA_API ConstIterator<char> end() const;
+    DATA_API iterator<char> begin();
+    DATA_API iterator<char> end();
+    DATA_API const_iterator<char> begin() const;
+    DATA_API const_iterator<char> end() const;
     /// @}
 
     ///
     /// @{
     /// Returns image buffer
     DATA_API void* getBuffer();
-    DATA_API void* getBuffer() const;
+    DATA_API const void* getBuffer() const;
     /// @}
 
     /**
@@ -465,17 +439,11 @@ public:
         void* buf,
         bool takeOwnership,
         const core::tools::Type& type,
-        const data::Image::Size& size,
+        const Image::Size& size,
+        PixelFormat format,
         core::memory::BufferAllocationPolicy::sptr policy = core::memory::BufferMallocPolicy::New()
     );
 
-    /** @{
-     *  @brief Get/set pixel format
-     */
-    PixelFormat getPixelFormat() const;
-    void setPixelFormat(PixelFormat format);
-    /// @}
-
     /**
      * @{
      * @brief Get the value of an element
@@ -485,8 +453,8 @@ public:
      *
      * @return Buffer value cast to T
      * @warning This method is slow and should not be used intensively
-     * @throw data::Exception The buffer cannot be accessed if the array is not locked (see lock())
-     * @throw data::Exception Index out of bounds
+     * @throw Exception The buffer cannot be accessed if the array is not locked (see dump_lock_impl())
+     * @throw Exception Index out of bounds
      */
     template<typename T>
     T& at(IndexType id);
@@ -505,8 +473,8 @@ public:
      *
      * @return Buffer value cast to T
      * @warning This method is slow and should not be used intensively
-     * @throw data::Exception The buffer cannot be accessed if the array is not locked (see lock())
-     * @throw data::Exception Index out of bounds
+     * @throw Exception The buffer cannot be accessed if the array is not locked (see dump_lock_impl())
+     * @throw Exception Index out of bounds
      */
     template<typename T>
     T& at(IndexType x, IndexType y, IndexType z, IndexType c = 0);
@@ -518,24 +486,24 @@ public:
     /**
      * @brief Return a pointer on a image pixel
      * @param index offset of the pixel
-     * @throw data::Exception The buffer cannot be accessed if the array is not locked (see lock())
+     * @throw Exception The buffer cannot be accessed if the array is not locked (see dump_lock_impl())
      */
-    DATA_API void* getPixelBuffer(IndexType index);
+    DATA_API void* getPixel(IndexType index);
 
     /**
      * @brief Return a pointer on a image pixel
      * @param index offset of the pixel
-     * @throw data::Exception The buffer cannot be accessed if the array is not locked (see lock())
+     * @throw Exception The buffer cannot be accessed if the array is not locked (see dump_lock_impl())
      */
-    DATA_API void* getPixelBuffer(IndexType index) const;
+    DATA_API const void* getPixel(IndexType index) const;
 
     /**
      * @brief Set pixel value represented as a void* buffer
      * @param index offset of the pixel
      * @param pixBuf pixel value represented as a void* buffer
-     * @throw data::Exception The buffer cannot be accessed if the array is not locked (see lock())
+     * @throw Exception The buffer cannot be accessed if the array is not locked (see dump_lock_impl())
      */
-    DATA_API void setPixelBuffer(IndexType index, BufferType* pixBuf);
+    DATA_API void setPixel(IndexType index, BufferType* pixBuf);
 
     /// Return the pixel value in a std::string
     DATA_API const std::string getPixelAsString(
@@ -544,147 +512,48 @@ public:
         IndexType z
     ) const;
 
-    /**
-     * @brief Return a lock on the image to prevent from dumping the buffer on the disk
-     *
-     * When the buffer is dumped, the memory is released and the buffer will not be accessible. When lock() is called,
-     * the buffer is restored from the disk if it was dumped and as long as the core::memory::BufferObject::Lock is
-     * maintained, the buffer will not be dumped.
-     *
-     * An exception will be raised if you try to access while the array is not locked.
-     */
-    [[nodiscard]] DATA_API core::memory::BufferObject::Lock lock() const;
-
     /// Return the buffer object
     DATA_API core::memory::BufferObject::sptr getBufferObject();
 
     /// Return the buffer object
     DATA_API core::memory::BufferObject::csptr getBufferObject() const;
-    /**
-     * @brief Set a stream factory for the image's buffer manager
-     *
-     * The factory will be used to load the image on demand.
-     *
-     * @param factory core::memory::stream::in::IFactory stream factory
-     * @param size size of data provided by the stream
-     * @param sourceFile Filesystem path of the source file, if applicable
-     * @param format file format (RAW,RAWZ,OTHER), if sourceFile is provided
-     * @param policy Buffer allocation policy
-     */
-    DATA_API void setIStreamFactory(
-        const SPTR(core::memory::stream::in::IFactory)& factory,
-        const size_t size,
-        const std::filesystem::path& sourceFile                  = "",
-        const core::memory::FileFormatType format                = core::memory::OTHER,
-        const core::memory::BufferAllocationPolicy::sptr& policy = core::memory::BufferMallocPolicy::New()
-    );
 
-    // ---------------------------------------
-    // Deprecated API
-    // ---------------------------------------
-
-    /**
-     * @brief Image size type
-     */
-    [[deprecated("it will be removed in sight 22.0, use Size")]] typedef data::Array::SizeType SizeType;
-
-    [[deprecated("it will be removed in sight 22.0")]] typedef size_t BufferIndexType;
-
-    /**
-     * @brief Image spacing type
-     */
-    [[deprecated("it will be removed in sight 22.0, use Spacing")]] typedef std::vector<double> SpacingType;
-
-    /**
-     * @brief Image origin type
-     */
-    [[deprecated("it will be removed in sight 22.0, use Origin")]] typedef std::vector<double> OriginType;
-    /** @{
-     * @brief get/set image spacing
-     * @deprecated Use getSizeSpacing2()/setSpacing2(), it will be removed in sight 22.0
-     */
-
-    [[deprecated("it will be removed in sight 22.0, use getSpacing2()")]]
-    DATA_API const SpacingType& getSpacing() const;
-    [[deprecated("it will be removed in sight 22.0, use setSpacing2()")]]
-    DATA_API void setSpacing(const SpacingType& spacing);
+    /// Equality comparison operators
+    /// @{
+    DATA_API bool operator==(const Image& other) const noexcept;
+    DATA_API bool operator!=(const Image& other) const noexcept;
     /// @}
 
-    /** @{
-     * @brief get/set image origin
-     * @deprecated Use getOrigin2()/setOrigin2(), it will be removed in sight 22.0
-     */
-    [[deprecated("it will be removed in sight 22.0, use getOrigin2()")]]
-    DATA_API const OriginType& getOrigin() const;
-    [[deprecated("it will be removed in sight 22.0, use setOrigin2()")]]
-    DATA_API void setOrigin(const OriginType& origin);
-    /// @}
+protected:
 
-    /** @{
-     * @brief get/set image size
-     * @deprecated Use getSize2()/setSize2(), it will be removed in sight 22.0
-     */
-    [[deprecated("it will be removed in sight 22.0, use getSize2()")]]
-    DATA_API const SizeType& getSize() const;
-    [[deprecated("it will be removed in sight 22.0, use setSize2()")]]
-    DATA_API void setSize(const SizeType& size);
-    /// @}
+    /// Defines deep copy
+    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
 
-    /** @{
-     * @brief Allocate image
+    /// Add a lock on the image in the given vector to prevent from dumping the buffer on the disk
+    /// This is needed for IBuffered interface implementation
+    DATA_API void dump_lock_impl(std::vector<core::memory::BufferObject::Lock>& locks) const override;
+
+private:
+
+    /**
+       @{
+     * @brief Resize the image and allocate the memory if needed.
      *
-     * If the data array owns its buffer, these methods will always work (until it remain free memory)
+     * @param size array of size in each direction (x,y,z)
+     * @param type type of a single pixel component value
+     * @param format specify the ordering and the meaning of a pixel components
+     * @param realloc allows to not reallocate, for instance when importing directly the buffer with setBuffer()
+     *
+     * If the data array owns its buffer, this method will always work (until it remain free memory)
      * Otherwise an exception is thrown :
      *  - if m_dataArray does not own it buffer and image's size and type combination do not match anymore array's one
      *  - if there is no memory left
      *
      * @return Allocated size in bytes
-     * @deprecated Allocate methods will be removed in sight 22.0. Use resize() methods instead
      */
-    [[deprecated("it will be removed in sight 22.0, use resize() instead")]]
-    DATA_API size_t allocate();
-    [[deprecated("it will be removed in sight 22.0, use resize() instead")]]
-    DATA_API size_t allocate(
-        SizeType::value_type x,
-        SizeType::value_type y,
-        SizeType::value_type z,
-        const core::tools::Type& type,
-        size_t numberOfComponents = 1
-    );
-    [[deprecated("it will be removed in sight 22.0, use resize() instead")]]
-    DATA_API size_t allocate(const SizeType& size, const core::tools::Type& type, size_t numberOfComponents = 1);
+    DATA_API std::size_t _resize(const Size& size, const core::tools::Type& type, PixelFormat format, bool realloc);
     /// @}
 
-    /**
-     * @brief set data array
-     *
-     * @param[in] array data array
-     * @param[in] copyArrayInfo if true, the image will copy the size and type information from the array
-     *
-     */
-    [[deprecated("it will be removed in sight 22.0")]]
-    DATA_API void setDataArray(data::Array::sptr array, bool copyArrayInfo = true);
-
-    ///get data array
-    [[deprecated("it will be removed in sight 22.0")]]
-    DATA_API data::Array::sptr getDataArray() const;
-
-protected:
-
-    // To allow locked_ptr to access protected lockBuffer()
-    template<class DATATYPE>
-    friend class data::mt::locked_ptr;
-
-    /**
-     * @brief Add a lock on the image in the given vector to prevent from dumping the buffer on the disk
-     *
-     * This is needed for IBuffered interface implementation
-     * The buffer cannot be accessed if the image is not locked
-     */
-    DATA_API void lockBuffer(std::vector<core::memory::BufferObject::Lock>& locks) const override;
-
-private:
-
     /**
      * @brief Protected setter for the array buffer.
      * An existing buffer will be released if the array own it.
@@ -708,12 +577,6 @@ private:
     //! Origin of the image in 3D repair
     Origin m_origin {0., 0., 0.};
 
-    /// Deprecated: set as mutable to be able to change it according to m_size, m_spacing and m_origin when we call
-    /// the getters.
-    [[deprecated("will be removed in sight 22.0")]] mutable SizeType m_oldSize;
-    [[deprecated("will be removed in sight 22.0")]] mutable SpacingType m_oldSpacing;
-    [[deprecated("will be removed in sight 22.0")]] mutable OriginType m_oldOrigin;
-
     //! Preferred window center/with
     ///@{
     double m_windowCenter {0.};
@@ -721,7 +584,7 @@ private:
     ///@}
 
     //! Number of components
-    size_t m_numberOfComponents {1};
+    std::size_t m_numComponents {1};
 
     //! type of image pixel
     core::tools::Type m_type {core::tools::Type::s_UNSPECIFIED_TYPE};
@@ -730,7 +593,7 @@ private:
     PixelFormat m_pixelFormat {PixelFormat::UNDEFINED};
 
     //! image buffer
-    data::Array::sptr m_dataArray;
+    Array::sptr m_dataArray;
 };
 
 //-----------------------------------------------------------------------------
@@ -763,23 +626,9 @@ inline void Image::setWindowWidth(double val)
 
 //-----------------------------------------------------------------------------
 
-inline size_t Image::getNumberOfComponents() const
+inline std::size_t Image::numComponents() const
 {
-    return m_numberOfComponents;
-}
-
-//-----------------------------------------------------------------------------
-
-inline void Image::setNumberOfComponents(size_t val)
-{
-    m_numberOfComponents = val;
-}
-
-//-----------------------------------------------------------------------------
-
-inline void Image::setPixelFormat(PixelFormat format)
-{
-    m_pixelFormat = format;
+    return m_numComponents;
 }
 
 //-----------------------------------------------------------------------------
@@ -791,88 +640,119 @@ inline Image::PixelFormat Image::getPixelFormat() const
 
 //------------------------------------------------------------------------------
 
-inline const Image::Spacing& Image::getSpacing2() const
+inline const Image::Spacing& Image::getSpacing() const
 {
     return m_spacing;
 }
 
 //------------------------------------------------------------------------------
 
-inline void Image::setSpacing2(const Spacing& spacing)
+inline void Image::setSpacing(const Spacing& spacing)
 {
     m_spacing = spacing;
 }
 
 //------------------------------------------------------------------------------
 
-inline const Image::Origin& Image::getOrigin2() const
+inline const Image::Origin& Image::getOrigin() const
 {
     return m_origin;
 }
 
 //------------------------------------------------------------------------------
 
-inline void Image::setOrigin2(const Origin& origin)
+inline void Image::setOrigin(const Origin& origin)
 {
     m_origin = origin;
 }
 
 //------------------------------------------------------------------------------
 
-inline const Image::Size& Image::getSize2() const
+inline const Image::Size& Image::getSize() const
 {
     return m_size;
 }
 
 //------------------------------------------------------------------------------
 
-inline void Image::setSize2(const Size& size)
+template<typename T>
+inline Image::iterator<T> Image::begin()
 {
-    m_size = size;
+    return iterator<T>(static_cast<typename iterator<T>::pointer>(getBuffer()));
 }
 
 //------------------------------------------------------------------------------
 
-template<typename FORMAT>
-inline Image::Iterator<FORMAT> Image::begin()
+template<typename T>
+inline Image::iterator<T> Image::end()
 {
-    return Iterator<FORMAT>(this);
-}
-
-//------------------------------------------------------------------------------
-
-template<typename FORMAT>
-inline Image::Iterator<FORMAT> Image::end()
-{
-    auto itr = Iterator<FORMAT>(this);
-    itr += static_cast<typename Iterator<FORMAT>::difference_type>(this->getSizeInBytes() / sizeof(FORMAT));
+    auto itr = begin<T>();
+    itr += static_cast<typename iterator<T>::difference_type>(this->getSizeInBytes() / sizeof(T));
     return itr;
 }
 
 //------------------------------------------------------------------------------
 
-template<typename FORMAT>
-inline Image::ConstIterator<FORMAT> Image::begin() const
+template<typename T>
+inline Image::const_iterator<T> Image::begin() const
 {
-    return ConstIterator<FORMAT>(this);
+    return const_iterator<T>(static_cast<typename const_iterator<T>::pointer>(getBuffer()));
 }
 
 //------------------------------------------------------------------------------
 
-template<typename FORMAT>
-inline Image::ConstIterator<FORMAT> Image::end() const
+template<typename T>
+inline Image::const_iterator<T> Image::end() const
 {
-    auto itr = ConstIterator<FORMAT>(this);
-    itr += static_cast<typename Iterator<FORMAT>::difference_type>(this->getSizeInBytes() / sizeof(FORMAT));
+    auto itr = begin<T>();
+    itr += static_cast<typename const_iterator<T>::difference_type>(this->getSizeInBytes() / sizeof(T));
     return itr;
 }
 
 //------------------------------------------------------------------------------
 
+template<typename T>
+inline Image::const_iterator<T> Image::cbegin() const
+{
+    return const_iterator<T>(static_cast<typename const_iterator<T>::pointer>(getBuffer()));
+}
+
+//------------------------------------------------------------------------------
+
+template<typename T>
+inline Image::const_iterator<T> Image::cend() const
+{
+    auto itr = begin<T>();
+    itr += static_cast<typename const_iterator<T>::difference_type>(this->getSizeInBytes() / sizeof(T));
+    return itr;
+}
+
+//------------------------------------------------------------------------------
+
+template<typename T>
+auto Image::range()
+{
+    auto b = begin<T>();
+    auto e = end<T>();
+    return boost::make_iterator_range(b, e);
+}
+
+//------------------------------------------------------------------------------
+
+template<typename T>
+auto Image::crange() const
+{
+    auto b = cbegin<T>();
+    auto e = cend<T>();
+    return boost::make_iterator_range(b, e);
+}
+
+//------------------------------------------------------------------------------
+
 template<typename T>
 inline T& Image::at(IndexType id)
 {
-    return *reinterpret_cast<T*>(this->getPixelBuffer(id));
+    return *reinterpret_cast<T*>(this->getPixel(id));
 }
 
 //------------------------------------------------------------------------------
@@ -880,7 +760,7 @@ inline T& Image::at(IndexType id)
 template<typename T>
 inline T Image::at(IndexType id) const
 {
-    return *reinterpret_cast<T*>(this->getPixelBuffer(id));
+    return *reinterpret_cast<const T*>(this->getPixel(id));
 }
 
 //------------------------------------------------------------------------------
@@ -889,7 +769,7 @@ template<typename T>
 inline T& Image::at(IndexType x, IndexType y, IndexType z, IndexType c)
 {
     const IndexType offset = x + m_size[0] * y + z * m_size[0] * m_size[1];
-    return *(reinterpret_cast<T*>(this->getPixelBuffer(offset)) + c);
+    return *(reinterpret_cast<T*>(this->getPixel(offset)) + c);
 }
 
 //------------------------------------------------------------------------------
@@ -898,9 +778,7 @@ template<typename T>
 inline T Image::at(IndexType x, IndexType y, IndexType z, IndexType c) const
 {
     const IndexType offset = x + m_size[0] * y + z * m_size[0] * m_size[1];
-    return *(reinterpret_cast<T*>(this->getPixelBuffer(offset)) + c);
+    return *(reinterpret_cast<const T*>(this->getPixel(offset)) + c);
 }
 
-//-----------------------------------------------------------------------------
-
 } // namespace sight::data
