@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2017 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -20,17 +20,14 @@
  *
  ***********************************************************************/
 
-#pragma once
-
 #include <core/base.hpp>
 #include <core/com/HasSignals.hpp>
 #include <core/com/Signal.hpp>
 #include <core/FactoryRegistry.hpp>
 #include <core/macros.hpp>
 #include <core/mt/types.hpp>
+#include <core/tools/compare.hpp>
 #include <core/tools/Object.hpp>
 
-#include <camp/userobject.hpp>
-
 #include <string>
 #include <unordered_map>
