@@ -31,7 +31,7 @@ namespace registry
 {
 
 #define SIGHT_REGISTER_DATA(classname) \
-    static ::sight::data::Object::Registry<classname> BOOST_PP_CAT(s__factory__record__, __LINE__);
+    static sight::data::Object::Registry<classname> BOOST_PP_CAT(s__factory__record__, __LINE__);
 
 } // end namespace registry
 
