@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,8 +22,6 @@
 
 #include "service/IService.hpp"
 
-#include "core/thread/ActiveWorkers.hpp"
-
 #include "service/registry/ObjectService.hpp"
 #include "service/registry/Proxy.hpp"
 
@@ -120,7 +118,11 @@ void IService::info(std::ostream&)
 
 //-----------------------------------------------------------------------------
 
-data::Object::csptr IService::getObject(std::string_view _key, data::Access _access, size_t _index) const
+data::Object::csptr IService::getObject(
+    std::string_view _key,
+    data::Access _access,
+    std::optional<std::size_t> _index
+) const
 {
     const auto key = std::make_pair(std::string(_key), _index);
     if(_access == data::Access::in)
@@ -153,7 +155,7 @@ data::Object::csptr IService::getObject(std::string_view _key, data::Access _acc
 
 //-----------------------------------------------------------------------------
 
-void IService::setOutput(std::string_view key, data::Object::sptr object, size_t index)
+void IService::setOutput(std::string_view key, data::Object::sptr object, std::optional<std::size_t> index)
 {
     this->_setOutput(key, object, index);
 
@@ -162,7 +164,7 @@ void IService::setOutput(std::string_view key, data::Object::sptr object, size_t
 
 //-----------------------------------------------------------------------------
 
-void IService::_setOutput(std::string_view key, data::Object::sptr object, size_t index)
+void IService::_setOutput(std::string_view key, data::Object::sptr object, std::optional<std::size_t> index)
 {
     auto keyPair = std::make_pair(std::string(key), index);
     if(m_outputsMap.find(keyPair) != m_outputsMap.end())
@@ -186,7 +188,7 @@ void IService::_setOutput(std::string_view key, data::Object::sptr object, size_
 void IService::setInput(
     data::Object::csptr obj,
     std::string_view key,
-    size_t index
+    std::optional<std::size_t> index
 )
 {
     this->_setInput(obj, key, index);
@@ -199,7 +201,7 @@ void IService::setInput(
     std::string_view key,
     const bool autoConnect,
     const bool optional,
-    size_t index
+    std::optional<std::size_t> index
 )
 {
     this->_registerObject(key, data::Access::in, index, autoConnect, optional);
@@ -211,7 +213,7 @@ void IService::setInput(
 void IService::_setInput(
     data::Object::csptr obj,
     std::string_view key,
-    size_t index
+    std::optional<std::size_t> index
 )
 {
     auto keyPair = std::make_pair(std::string(key), index);
@@ -234,7 +236,7 @@ void IService::_setInput(
 void IService::setInOut(
     data::Object::sptr obj,
     std::string_view key,
-    size_t index
+    std::optional<std::size_t> index
 )
 {
     this->_setInOut(obj, key, index);
@@ -247,7 +249,7 @@ void IService::setInOut(
     std::string_view key,
     const bool autoConnect,
     const bool optional,
-    size_t index
+    std::optional<std::size_t> index
 )
 {
     this->_registerObject(key, data::Access::inout, index, autoConnect, optional);
@@ -259,7 +261,7 @@ void IService::setInOut(
 void IService::_setInOut(
     data::Object::sptr obj,
     std::string_view key,
-    size_t index
+    std::optional<std::size_t> index
 )
 {
     auto keyPair = std::make_pair(std::string(key), index);
@@ -282,7 +284,7 @@ void IService::_setInOut(
 void IService::setObject(
     data::Object::sptr obj,
     std::string_view key,
-    size_t index,
+    std::optional<std::size_t> index,
     data::Access access,
     const bool autoConnect,
     const bool optional
@@ -315,7 +317,7 @@ void IService::setObject(
 
 void IService::resetObject(
     std::string_view key,
-    size_t index,
+    std::optional<std::size_t> index,
     data::Access access
 )
 {
@@ -346,7 +348,7 @@ void IService::registerObject(
     const data::Access access,
     const bool autoConnect,
     const bool optional,
-    size_t index
+    std::optional<std::size_t> index
 )
 {
     // TODO: remove this method, should be replaced by a correct usage of data::ptr + setObjectId() or its replacement
@@ -357,7 +359,7 @@ void IService::registerObject(
 
 //-----------------------------------------------------------------------------
 
-bool IService::hasObjectId(std::string_view _key, const size_t _index) const
+bool IService::hasObjectId(std::string_view _key, std::optional<std::size_t> _index) const
 {
     bool hasId = false;
     if(auto itr = m_serviceConfig.m_objects.find({std::string(_key), _index}); itr != m_serviceConfig.m_objects.end())
@@ -370,7 +372,7 @@ bool IService::hasObjectId(std::string_view _key, const size_t _index) const
 
 //-----------------------------------------------------------------------------
 
-IService::IdType IService::getObjectId(std::string_view _key, const size_t _index) const
+IService::IdType IService::getObjectId(std::string_view _key, std::optional<std::size_t> _index) const
 {
     auto keyItr = m_serviceConfig.m_objects.find({std::string(_key), _index});
     SIGHT_THROW_IF(
@@ -386,8 +388,18 @@ IService::IdType IService::getObjectId(std::string_view _key, const size_t _inde
 
 //-----------------------------------------------------------------------------
 
-void IService::setObjectId(std::string_view _key, const IService::IdType& _id, const size_t _index)
+void IService::setObjectId(std::string_view _key, const IService::IdType& _id, std::optional<std::size_t> _index)
 {
+    if(_index != std::nullopt)
+    {
+        if(auto keyItr = m_serviceConfig.m_objects.find({std::string(_key), _index});
+           keyItr == m_serviceConfig.m_objects.end())
+        {
+            // Create a new group member from the group config
+            m_serviceConfig.m_objects[{std::string(_key), _index}] = m_serviceConfig.m_groups[{std::string(_key)}];
+        }
+    }
+
     auto keyItr = m_serviceConfig.m_objects.find({std::string(_key), _index});
     SIGHT_THROW_IF(
         "key '" << _key << "' is not registered for '" << this->getID() << "'.",
@@ -399,11 +411,11 @@ void IService::setObjectId(std::string_view _key, const IService::IdType& _id, c
 
 //-----------------------------------------------------------------------------
 
-void displayPt(::boost::property_tree::ptree& pt, std::string indent = "")
+void displayPt(boost::property_tree::ptree& pt, std::string indent = "")
 {
     SIGHT_ERROR(indent << " data : '" << pt.data() << "'");
 
-    for(::boost::property_tree::ptree::value_type& v : pt)
+    for(boost::property_tree::ptree::value_type& v : pt)
     {
         SIGHT_ERROR((indent + "  '") << v.first << "':");
         displayPt(v.second, indent + "      ");
@@ -429,7 +441,20 @@ void IService::setConfiguration(const Config& _configuration)
     m_configuration      = core::runtime::ConfigurationElement::constCast(_configuration.m_config);
     m_configurationState = UNCONFIGURED;
 
-    m_serviceConfig = _configuration;
+    m_serviceConfig.m_uid               = _configuration.m_uid;
+    m_serviceConfig.m_type              = _configuration.m_type;
+    m_serviceConfig.m_globalAutoConnect = _configuration.m_globalAutoConnect;
+    m_serviceConfig.m_worker            = _configuration.m_worker;
+    m_serviceConfig.m_config            = _configuration.m_config;
+
+    // Only copy missing entries
+    for(const auto& [key, objectCfg] : _configuration.m_objects)
+    {
+        if(auto it = m_serviceConfig.m_objects.find(key); it == m_serviceConfig.m_objects.end())
+        {
+            m_serviceConfig.m_objects[key] = objectCfg;
+        }
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -466,14 +491,14 @@ IService::ConfigType IService::getConfigTree() const
 
     if(srvConfig.is_initialized())
     {
-        return srvConfig.value();
+        return srvConfig.get();
     }
     else
     {
         srvConfig = configTree.get_child_optional("service");
         if(srvConfig.is_initialized())
         {
-            return srvConfig.value();
+            return srvConfig.get();
         }
 
         return IService::ConfigType();
@@ -683,7 +708,7 @@ IService::SharedFutureType IService::_start(bool _async)
 
         if(!_async)
         {
-            // The future is shared, thus the caller can still catch the exception if needed with ufuture.get()
+            // The future is shared, thus the caller can still catch the exception if needed with future.get()
             return future;
         }
         else
@@ -737,7 +762,7 @@ IService::SharedFutureType IService::_stop(bool _async)
 
         if(!_async)
         {
-            // The future is shared, thus the caller can still catch the exception if needed with ufuture.get()
+            // The future is shared, thus the caller can still catch the exception if needed with future.get()
             return future;
         }
         else
@@ -794,7 +819,7 @@ IService::SharedFutureType IService::_swapKey(std::string_view _key, data::Objec
 
         if(!_async)
         {
-            // The future is shared, thus the caller can still catch the exception if needed with ufuture.get()
+            // The future is shared, thus the caller can still catch the exception if needed with future.get()
             return future;
         }
         else
@@ -855,7 +880,7 @@ IService::SharedFutureType IService::_update(bool _async)
         m_updatingState = NOTUPDATING;
         if(!_async)
         {
-            // The future is shared, thus the caller can still catch the exception if needed with ufuture.get()
+            // The future is shared, thus the caller can still catch the exception if needed with future.get()
             return future;
         }
         else
@@ -1134,6 +1159,37 @@ bool IService::hasAllRequiredObjects() const
         }
     }
 
+    for(const auto& [key, objectCfg] : m_serviceConfig.m_groups)
+    {
+        if(objectCfg.m_optional == false)
+        {
+            if(objectCfg.m_access == data::Access::in)
+            {
+                if(m_inputsMap.find({key, 0}) == m_inputsMap.end())
+                {
+                    SIGHT_DEBUG(
+                        "The 'input' object with key '" + objectCfg.m_key + "' is missing for '" + this->getID()
+                        + "'"
+                    );
+                    hasAllObjects = false;
+                    break;
+                }
+            }
+            else if(objectCfg.m_access == data::Access::inout)
+            {
+                if(m_inOutsMap.find({key, 0}) == m_inOutsMap.end())
+                {
+                    SIGHT_DEBUG(
+                        "The 'input' object with key '" + objectCfg.m_key + "' is missing for '" + this->getID()
+                        + "'"
+                    );
+                    hasAllObjects = false;
+                    break;
+                }
+            }
+        }
+    }
+
     return hasAllObjects;
 }
 
@@ -1172,12 +1228,12 @@ SERVICE_API void IService::notify(NotificationType type, const std::string& mess
 
 //------------------------------------------------------------------------------
 
-std::optional<std::tuple<const std::string&, size_t,
+std::optional<std::tuple<const std::string&, std::optional<std::size_t>,
                          const service::IService::ObjectServiceConfig&> > IService::_getObjInfoFromId(
     const std::string& objId
 ) const
 {
-    auto idItr = std::find_if(
+    const auto idItr = std::find_if(
         m_serviceConfig.m_objects.begin(),
         m_serviceConfig.m_objects.end(),
         [&](const auto& objCfg)
@@ -1195,12 +1251,43 @@ std::optional<std::tuple<const std::string&, size_t,
                                                       );
 }
 
+//------------------------------------------------------------------------------
+
+const service::IService::ObjectServiceConfig* IService::_getObjInfoFromKey(const std::string& objKey) const
+{
+    {
+        auto idItr = std::find_if(
+            m_serviceConfig.m_objects.begin(),
+            m_serviceConfig.m_objects.end(),
+            [&](const auto& objCfg)
+            {
+                return objCfg.second.m_key == objKey;
+            });
+
+        if(idItr != m_serviceConfig.m_objects.end())
+        {
+            return &idItr->second;
+        }
+    }
+    {
+        auto idItr = std::find_if(
+            m_serviceConfig.m_groups.begin(),
+            m_serviceConfig.m_groups.end(),
+            [&](const auto& objCfg)
+            {
+                return objCfg.second.m_key == objKey;
+            });
+
+        return (idItr == m_serviceConfig.m_groups.end()) ? nullptr : &idItr->second;
+    }
+}
+
 //-----------------------------------------------------------------------------
 
 void IService::_registerObject(
     const std::string_view key,
     const data::Access access,
-    size_t index,
+    std::optional<std::size_t> index,
     const bool autoConnect,
     const bool optional
 )
@@ -1215,6 +1302,16 @@ void IService::_registerObject(
         objConfig.m_autoConnect = autoConnect;
         objConfig.m_optional    = optional;
 
+        if(index.has_value())
+        {
+            [[maybe_unused]] const ObjectServiceConfig& groupConfig = m_serviceConfig.m_groups[std::string(key)];
+
+            SIGHT_ASSERT(
+                "Access type of '" << key << "'  does not match previous registration",
+                access == groupConfig.m_access
+            );
+        }
+
         m_serviceConfig.m_objects[keyPair] = objConfig;
     }
     else
@@ -1222,7 +1319,7 @@ void IService::_registerObject(
         ObjectServiceConfig& objConfig = itr->second;
 
         SIGHT_ASSERT(
-            "Object '" << key << "' access type does not match previous registration",
+            "[" << this->getID() << "] " << "access type of '" << key << "'  does not match previous registration",
             access == objConfig.m_access
         );
 
@@ -1236,22 +1333,17 @@ void IService::_registerObject(
 void IService::_registerObjectGroup(
     std::string_view key,
     const data::Access access,
-    const std::uint8_t minNbObject,
     const bool autoConnect,
-    const std::uint8_t maxNbObject
+    const bool optional
 )
 {
-    for(std::uint8_t i = 0 ; i < maxNbObject ; ++i)
-    {
-        const bool optional = (i < minNbObject ? false : true);
-        ObjectServiceConfig objConfig;
-        objConfig.m_key         = KEY_GROUP_NAME(key, i);
-        objConfig.m_access      = access;
-        objConfig.m_autoConnect = autoConnect;
-        objConfig.m_optional    = optional;
+    ObjectServiceConfig objConfig;
+    objConfig.m_key         = key;
+    objConfig.m_access      = access;
+    objConfig.m_autoConnect = autoConnect;
+    objConfig.m_optional    = optional;
 
-        m_serviceConfig.m_objects[{std::string(key), i}] = objConfig;
-    }
+    m_serviceConfig.m_groups[std::string(key)] = objConfig;
 }
 
 //-----------------------------------------------------------------------------
