@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,6 +23,7 @@
 #include "service/extension/Config.hpp"
 #include "service/helper/Config.hpp"
 
+#include "service/extension/Factory.hpp"
 #include "service/registry/Proxy.hpp"
 
 #include <core/com/HasSignals.hpp>
@@ -394,56 +395,69 @@ service::IService::Config Config::parseService(
             SIGHT_FATAL("Unreachable code");
         }
 
-        // AutoConnect
-        objConfig.m_autoConnect = core::runtime::get_ptree_value(cfg.second, "<xmlattr>.autoConnect", false);
-
-        // Optional
-        if(objConfig.m_access != data::Access::out)
-        {
-            objConfig.m_optional = core::runtime::get_ptree_value(cfg.second, "<xmlattr>.optional", false);
-        }
-        else
-        {
-            objConfig.m_optional = true;
-        }
-
         // Do we use groups ?
         const auto group = cfg.second.get_optional<std::string>("<xmlattr>.group");
         if(group)
         {
-            auto keyCfgs = cfg.second.equal_range("key");
+            auto keyCfgs          = cfg.second.equal_range("key");
+            const std::string key = group.value();
+            auto defaultCfg       = getKeyProps(srvConfig.m_type, key);
 
-            size_t count = 0;
+            objConfig.m_autoConnect = core::runtime::get_ptree_value(
+                cfg.second,
+                "<xmlattr>.autoConnect",
+                defaultCfg != nullptr ? defaultCfg->m_autoConnect : false
+            );
+
+            // Optional is global to all keys in the group
+            if(objConfig.m_access != data::Access::out)
+            {
+                objConfig.m_optional = core::runtime::get_ptree_value(
+                    cfg.second,
+                    "<xmlattr>.optional",
+                    defaultCfg != nullptr ? defaultCfg->m_optional : false
+                );
+            }
+            else
+            {
+                objConfig.m_optional = true;
+            }
+
+            std::size_t count = 0;
             for(auto groupCfg = keyCfgs.first ; groupCfg != keyCfgs.second ; ++groupCfg)
             {
-                service::IService::ObjectServiceConfig grouObjConfig = objConfig;
+                service::IService::ObjectServiceConfig groupObjConfig = objConfig;
 
                 // Identifier
-                grouObjConfig.m_uid = groupCfg->second.get<std::string>("<xmlattr>.uid", "");
-                SIGHT_ASSERT(errMsgHead + "\"uid\" attribute is empty" + errMsgTail, !grouObjConfig.m_uid.empty());
+                groupObjConfig.m_uid = groupCfg->second.get<std::string>("<xmlattr>.uid", "");
+                SIGHT_ASSERT(errMsgHead + "\"uid\" attribute is empty" + errMsgTail, !groupObjConfig.m_uid.empty());
 
-                const std::string key = group.value();
-                const size_t index    = count++;
-                grouObjConfig.m_key = KEY_GROUP_NAME(key, index);
+                const std::size_t index = count++;
+                groupObjConfig.m_key = KEY_GROUP_NAME(key, index);
 
-                // AutoConnect
-                grouObjConfig.m_autoConnect = core::runtime::get_ptree_value(
+                // AutoConnect can be overriden by element in the group
+                groupObjConfig.m_autoConnect = core::runtime::get_ptree_value(
                     groupCfg->second,
                     "<xmlattr>.autoConnect",
-                    grouObjConfig.m_autoConnect
+                    groupObjConfig.m_autoConnect
                 );
 
-                // Optional
-                if(grouObjConfig.m_access != data::Access::out)
+                // Optional can be overriden by element in the group
+                if(groupObjConfig.m_access != data::Access::out)
                 {
-                    grouObjConfig.m_optional = core::runtime::get_ptree_value(
+                    groupObjConfig.m_optional = core::runtime::get_ptree_value(
                         groupCfg->second,
                         "<xmlattr>.optional",
-                        false
+                        groupObjConfig.m_optional
                     );
                 }
+                else
+                {
+                    groupObjConfig.m_optional = true;
+                }
 
-                srvConfig.m_objects[{key, index}] = grouObjConfig;
+                // Assign the current object config in the service config
+                srvConfig.m_objects[{key, index}] = groupObjConfig;
             }
         }
         else
@@ -456,7 +470,31 @@ service::IService::Config Config::parseService(
             objConfig.m_key = cfg.second.get<std::string>("<xmlattr>.key", "");
             SIGHT_ASSERT(errMsgHead + "Missing object attribute 'key'" + errMsgTail, !objConfig.m_key.empty());
 
-            srvConfig.m_objects[{objConfig.m_key, 0}] = objConfig;
+            auto defaultCfg = getKeyProps(srvConfig.m_type, objConfig.m_key);
+
+            // AutoConnect
+            objConfig.m_autoConnect = core::runtime::get_ptree_value(
+                cfg.second,
+                "<xmlattr>.autoConnect",
+                defaultCfg != nullptr ? defaultCfg->m_autoConnect : false
+            );
+
+            // Optional
+            if(objConfig.m_access != data::Access::out)
+            {
+                objConfig.m_optional = core::runtime::get_ptree_value(
+                    cfg.second,
+                    "<xmlattr>.optional",
+                    defaultCfg != nullptr ? defaultCfg->m_optional : false
+                );
+            }
+            else
+            {
+                objConfig.m_optional = true;
+            }
+
+            // Assign the current object config in the service config
+            srvConfig.m_objects[{objConfig.m_key, std::nullopt}] = objConfig;
         }
     }
 
@@ -465,6 +503,40 @@ service::IService::Config Config::parseService(
 
 // ----------------------------------------------------------------------------
 
+static std::map<std::string, service::IService::sptr> s_servicesProps;
+
+//------------------------------------------------------------------------------
+
+const service::IService::ObjectServiceConfig* Config::getKeyProps(
+    const std::string& serviceType,
+    const std::string& key
+)
+{
+    service::IService::sptr srv;
+    auto it = s_servicesProps.find(serviceType);
+    if(it == s_servicesProps.end())
+    {
+        service::extension::Factory::sptr srvFactory = service::extension::Factory::getDefault();
+        srv                          = srvFactory->create(serviceType);
+        s_servicesProps[serviceType] = srv;
+    }
+    else
+    {
+        srv = it->second;
+    }
+
+    return srv->_getObjInfoFromKey(key);
+}
+
+// ----------------------------------------------------------------------------
+
+void Config::clearKeyProps()
+{
+    s_servicesProps.clear();
+}
+
+// ----------------------------------------------------------------------------
+
 } // namespace helper
 
 } // namespace sight::service
