@@ -28,7 +28,7 @@
 #include <data/Vector.hpp>
 
 SIGHT_REGISTER_SERVICE(
-    ::sight::service::ut::TestConfigService,
-    ::sight::service::ut::STest1Image,
-    ::sight::data::Image
+    sight::service::ut::TestConfigService,
+    sight::service::ut::STest1Image,
+    sight::data::Image
 );
