@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2021 IRCAD France
+ * Copyright (C) 2017-2022 IRCAD France
  * Copyright (C) 2017-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,17 +28,17 @@
 #include <geometry/data/Matrix4.hpp>
 #include <geometry/vision/helper.hpp>
 
+#include <utestData/Data.hpp>
+
 #include <glm/glm.hpp>
 #include <glm/gtc/matrix_transform.hpp>
 
-#include <utestData/Data.hpp>
-
 #include <opencv2/core.hpp>
 #include <opencv2/highgui.hpp>
 #include <opencv2/imgproc.hpp>
 
 // Registers the fixture into the 'registry'
-CPPUNIT_TEST_SUITE_REGISTRATION(::sight::geometry::vision::ut::helperTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(sight::geometry::vision::ut::helperTest);
 
 namespace sight::geometry::vision
 {
@@ -52,10 +52,10 @@ using ExpectedChessboardType = std::vector<sight::data::Point::PointCoordArrayTy
 
 //------------------------------------------------------------------------------
 
-static inline const ::cv::Mat readRGBImage(const std::string _fname)
+static inline const cv::Mat readRGBImage(const std::string _fname)
 {
-    ::cv::Mat img = ::cv::imread(_fname, ::cv::IMREAD_COLOR);
-    ::cv::cvtColor(img, img, ::cv::COLOR_BGR2RGB);
+    cv::Mat img = cv::imread(_fname, cv::IMREAD_COLOR);
+    cv::cvtColor(img, img, cv::COLOR_BGR2RGB);
 
     return img;
 }
@@ -96,27 +96,27 @@ void helperTest::tearDown()
 
 void helperTest::reprojectionIdentity()
 {
-    std::vector< ::cv::Point3f> objectPoints;
-    objectPoints.push_back(::cv::Point3f(-30, 30, 0));
-    objectPoints.push_back(::cv::Point3f(30, 30, 0));
-    objectPoints.push_back(::cv::Point3f(30, -30, 0));
-    objectPoints.push_back(::cv::Point3f(-30, -30, 0));
+    std::vector<cv::Point3f> objectPoints;
+    objectPoints.push_back(cv::Point3f(-30, 30, 0));
+    objectPoints.push_back(cv::Point3f(30, 30, 0));
+    objectPoints.push_back(cv::Point3f(30, -30, 0));
+    objectPoints.push_back(cv::Point3f(-30, -30, 0));
 
-    std::vector< ::cv::Point2f> imagePoints;
-    imagePoints.push_back(::cv::Point2f(-30, 30));
-    imagePoints.push_back(::cv::Point2f(30, 30));
-    imagePoints.push_back(::cv::Point2f(30, -30));
-    imagePoints.push_back(::cv::Point2f(-30, -30));
+    std::vector<cv::Point2f> imagePoints;
+    imagePoints.push_back(cv::Point2f(-30, 30));
+    imagePoints.push_back(cv::Point2f(30, 30));
+    imagePoints.push_back(cv::Point2f(30, -30));
+    imagePoints.push_back(cv::Point2f(-30, -30));
 
-    ::cv::Mat rvec, tvec;
-    ::cv::Mat cameraMatrix;
-    ::cv::Mat distorsion;
+    cv::Mat rvec, tvec;
+    cv::Mat cameraMatrix;
+    cv::Mat distorsion;
 
-    rvec = ::cv::Mat::zeros(3, 1, CV_64F);
-    tvec = ::cv::Mat::zeros(3, 1, CV_64F);
+    rvec = cv::Mat::zeros(3, 1, CV_64F);
+    tvec = cv::Mat::zeros(3, 1, CV_64F);
 
-    cameraMatrix = ::cv::Mat::eye(3, 3, CV_64F);
-    distorsion   = ::cv::Mat::zeros(5, 1, CV_64F);
+    cameraMatrix = cv::Mat::eye(3, 3, CV_64F);
+    distorsion   = cv::Mat::zeros(5, 1, CV_64F);
 
     geometry::vision::helper::ErrorAndPointsType result =
         geometry::vision::helper::computeReprojectionError(
@@ -132,8 +132,8 @@ void helperTest::reprojectionIdentity()
 
     for(unsigned int i = 0 ; i < 4 ; ++i)
     {
-        ::cv::Point2f expected = imagePoints[i];
-        ::cv::Point2f actual   = result.second[i];
+        cv::Point2f expected = imagePoints[i];
+        cv::Point2f actual   = result.second[i];
 
         CPPUNIT_ASSERT_DOUBLES_EQUAL(
             static_cast<double>(expected.x),
@@ -152,29 +152,29 @@ void helperTest::reprojectionIdentity()
 
 void helperTest::reprojectionRealDatasetTest1()
 {
-    std::vector< ::cv::Point3f> objectPoints;
-    objectPoints.push_back(::cv::Point3f(-30, 30, 0));
-    objectPoints.push_back(::cv::Point3f(30, 30, 0));
-    objectPoints.push_back(::cv::Point3f(30, -30, 0));
-    objectPoints.push_back(::cv::Point3f(-30, -30, 0));
+    std::vector<cv::Point3f> objectPoints;
+    objectPoints.push_back(cv::Point3f(-30, 30, 0));
+    objectPoints.push_back(cv::Point3f(30, 30, 0));
+    objectPoints.push_back(cv::Point3f(30, -30, 0));
+    objectPoints.push_back(cv::Point3f(-30, -30, 0));
 
-    std::vector< ::cv::Point2f> imagePoints;
+    std::vector<cv::Point2f> imagePoints;
 
-    ::cv::Mat rvec, tvec;
-    ::cv::Mat cameraMatrix;
-    ::cv::Mat distorsion;
+    cv::Mat rvec, tvec;
+    cv::Mat cameraMatrix;
+    cv::Mat distorsion;
 
-    rvec = ::cv::Mat::zeros(3, 1, CV_64F);
-    tvec = ::cv::Mat::zeros(3, 1, CV_64F);
+    rvec = cv::Mat::zeros(3, 1, CV_64F);
+    tvec = cv::Mat::zeros(3, 1, CV_64F);
 
-    cameraMatrix = ::cv::Mat::eye(3, 3, CV_64F);
-    distorsion   = ::cv::Mat::zeros(5, 1, CV_64F);
+    cameraMatrix = cv::Mat::eye(3, 3, CV_64F);
+    distorsion   = cv::Mat::zeros(5, 1, CV_64F);
 
     //Values from real dataset 1
-    imagePoints.push_back(::cv::Point2f(220.92876f, 224.95102f));
-    imagePoints.push_back(::cv::Point2f(393.3707f, 216.15828f));
-    imagePoints.push_back(::cv::Point2f(416.92828f, 365.78033f));
-    imagePoints.push_back(::cv::Point2f(207.39848f, 375.8844f));
+    imagePoints.push_back(cv::Point2f(220.92876f, 224.95102f));
+    imagePoints.push_back(cv::Point2f(393.3707f, 216.15828f));
+    imagePoints.push_back(cv::Point2f(416.92828f, 365.78033f));
+    imagePoints.push_back(cv::Point2f(207.39848f, 375.8844f));
 
     rvec.at<double>(0) = 2.428872194668891;
     rvec.at<double>(1) = -0.04640821030480094;
@@ -196,11 +196,11 @@ void helperTest::reprojectionRealDatasetTest1()
     distorsion.at<double>(3) = -0.007336273789405823; //p2
     distorsion.at<double>(4) = 0.6075565814971924;    //k3
 
-    std::vector< ::cv::Point2f> reprojectedPoints_expected;
-    reprojectedPoints_expected.push_back(::cv::Point2f(220.89903f, 224.99107f));
-    reprojectedPoints_expected.push_back(::cv::Point2f(393.38748f, 216.12437f));
-    reprojectedPoints_expected.push_back(::cv::Point2f(416.922f, 365.82419f));
-    reprojectedPoints_expected.push_back(::cv::Point2f(207.41541f, 375.83548f));
+    std::vector<cv::Point2f> reprojectedPoints_expected;
+    reprojectedPoints_expected.push_back(cv::Point2f(220.89903f, 224.99107f));
+    reprojectedPoints_expected.push_back(cv::Point2f(393.38748f, 216.12437f));
+    reprojectedPoints_expected.push_back(cv::Point2f(416.922f, 365.82419f));
+    reprojectedPoints_expected.push_back(cv::Point2f(207.41541f, 375.83548f));
 
     const double expectedErr = 0.0462637;
 
@@ -218,8 +218,8 @@ void helperTest::reprojectionRealDatasetTest1()
 
     for(unsigned int i = 0 ; i < 4 ; ++i)
     {
-        ::cv::Point2f expected = reprojectedPoints_expected[i];
-        ::cv::Point2f actual   = result.second[i];
+        cv::Point2f expected = reprojectedPoints_expected[i];
+        cv::Point2f actual   = result.second[i];
 
         CPPUNIT_ASSERT_DOUBLES_EQUAL(
             static_cast<double>(expected.x),
@@ -238,29 +238,29 @@ void helperTest::reprojectionRealDatasetTest1()
 
 void helperTest::reprojectionRealDatasetTest2()
 {
-    std::vector< ::cv::Point3f> objectPoints;
-    objectPoints.push_back(::cv::Point3f(-30, 30, 0));
-    objectPoints.push_back(::cv::Point3f(30, 30, 0));
-    objectPoints.push_back(::cv::Point3f(30, -30, 0));
-    objectPoints.push_back(::cv::Point3f(-30, -30, 0));
+    std::vector<cv::Point3f> objectPoints;
+    objectPoints.push_back(cv::Point3f(-30, 30, 0));
+    objectPoints.push_back(cv::Point3f(30, 30, 0));
+    objectPoints.push_back(cv::Point3f(30, -30, 0));
+    objectPoints.push_back(cv::Point3f(-30, -30, 0));
 
-    std::vector< ::cv::Point2f> imagePoints;
+    std::vector<cv::Point2f> imagePoints;
 
-    ::cv::Mat rvec, tvec;
-    ::cv::Mat cameraMatrix;
-    ::cv::Mat distorsion;
+    cv::Mat rvec, tvec;
+    cv::Mat cameraMatrix;
+    cv::Mat distorsion;
 
-    rvec = ::cv::Mat::zeros(3, 1, CV_64F);
-    tvec = ::cv::Mat::zeros(3, 1, CV_64F);
+    rvec = cv::Mat::zeros(3, 1, CV_64F);
+    tvec = cv::Mat::zeros(3, 1, CV_64F);
 
-    cameraMatrix = ::cv::Mat::eye(3, 3, CV_64F);
-    distorsion   = ::cv::Mat::zeros(5, 1, CV_64F);
+    cameraMatrix = cv::Mat::eye(3, 3, CV_64F);
+    distorsion   = cv::Mat::zeros(5, 1, CV_64F);
 
     //Values from real dataset 1
-    imagePoints.push_back(::cv::Point2f(232.76308f, 227.31705f));
-    imagePoints.push_back(::cv::Point2f(410.1149f, 220.90685f));
-    imagePoints.push_back(::cv::Point2f(434.63507f, 372.6174f));
-    imagePoints.push_back(::cv::Point2f(216.75545f, 379.34464f));
+    imagePoints.push_back(cv::Point2f(232.76308f, 227.31705f));
+    imagePoints.push_back(cv::Point2f(410.1149f, 220.90685f));
+    imagePoints.push_back(cv::Point2f(434.63507f, 372.6174f));
+    imagePoints.push_back(cv::Point2f(216.75545f, 379.34464f));
 
     rvec.at<double>(0) = 2.397315382812963;
     rvec.at<double>(1) = -0.02181686018178059;
@@ -282,11 +282,11 @@ void helperTest::reprojectionRealDatasetTest2()
     distorsion.at<double>(3) = -0.007336273789405823; //p2
     distorsion.at<double>(4) = 0.6075565814971924;    //k3
 
-    std::vector< ::cv::Point2f> reprojectedPoints_expected;
-    reprojectedPoints_expected.push_back(::cv::Point2f(232.92502f, 227.35114f));
-    reprojectedPoints_expected.push_back(::cv::Point2f(409.92566f, 220.82785f));
-    reprojectedPoints_expected.push_back(::cv::Point2f(434.73633f, 372.69672f));
-    reprojectedPoints_expected.push_back(::cv::Point2f(216.67587f, 379.3006f));
+    std::vector<cv::Point2f> reprojectedPoints_expected;
+    reprojectedPoints_expected.push_back(cv::Point2f(232.92502f, 227.35114f));
+    reprojectedPoints_expected.push_back(cv::Point2f(409.92566f, 220.82785f));
+    reprojectedPoints_expected.push_back(cv::Point2f(434.73633f, 372.69672f));
+    reprojectedPoints_expected.push_back(cv::Point2f(216.67587f, 379.3006f));
 
     const double expectedErr = 0.153504;
 
@@ -304,8 +304,8 @@ void helperTest::reprojectionRealDatasetTest2()
 
     for(unsigned int i = 0 ; i < 4 ; ++i)
     {
-        ::cv::Point2f expected = reprojectedPoints_expected[i];
-        ::cv::Point2f actual   = result.second[i];
+        cv::Point2f expected = reprojectedPoints_expected[i];
+        cv::Point2f actual   = result.second[i];
 
         CPPUNIT_ASSERT_DOUBLES_EQUAL(
             static_cast<double>(expected.x),
@@ -330,28 +330,28 @@ void helperTest::toolCalibrationBasic()
     sight::data::Matrix4::sptr resCenterMatrix    = sight::data::Matrix4::New();
     sight::data::Matrix4::sptr resTransformMatrix = sight::data::Matrix4::New();
 
-    const ::glm::dvec3 center(0., 0., 0.);
+    const glm::dvec3 center(0., 0., 0.);
     const double radius = 18;
-    const ::glm::dvec3 translation(radius, 0, 0);
+    const glm::dvec3 translation(radius, 0, 0);
 
     // generates matrices
-    for(size_t i = 0 ; i < nbMatrices ; ++i)
+    for(std::size_t i = 0 ; i < nbMatrices ; ++i)
     {
         const double angleInDegrees = safeRand() % 180;
-        const double angle          = ::glm::radians(angleInDegrees);
+        const double angle          = glm::radians(angleInDegrees);
 
         const double x = safeRand() % 100 / 100.;
         const double y = safeRand() % 100 / 100.;
         const double z = safeRand() % 100 / 100.;
 
-        ::glm::dvec3 axis(x, y, z);
+        glm::dvec3 axis(x, y, z);
         axis = glm::normalize(axis);
 
-        ::glm::dmat4 matrix = ::glm::translate(::glm::dmat4(1.), center);
+        glm::dmat4 matrix = glm::translate(glm::dmat4(1.), center);
 
-        matrix = ::glm::rotate(matrix, angle, axis);
+        matrix = glm::rotate(matrix, angle, axis);
 
-        matrix = ::glm::translate(matrix, translation);
+        matrix = glm::translate(matrix, translation);
 
         auto mat = sight::data::Matrix4::New();
         geometry::data::setTF3DFromMatrix(*mat, matrix);
@@ -405,25 +405,25 @@ void helperTest::toolCalibration()
     sight::data::Matrix4::sptr resCenterMatrix    = sight::data::Matrix4::New();
     sight::data::Matrix4::sptr resTransformMatrix = sight::data::Matrix4::New();
 
-    const ::glm::dvec3 center(36., 52., -530.);
-    const ::glm::dvec3 translation(-459.45, 46.6, -88.54);
+    const glm::dvec3 center(36., 52., -530.);
+    const glm::dvec3 translation(-459.45, 46.6, -88.54);
 
     // generates matrices
-    for(size_t i = 0 ; i < nbMatrices ; ++i)
+    for(std::size_t i = 0 ; i < nbMatrices ; ++i)
     {
         const double angleInDegrees = safeRand() % 360;
-        const double angle          = ::glm::radians(angleInDegrees);
+        const double angle          = glm::radians(angleInDegrees);
 
         const double x = safeRand() % 100 / 100.;
         const double y = safeRand() % 100 / 100.;
         const double z = safeRand() % 100 / 100.;
 
-        ::glm::dvec3 axis(x, y, z);
+        glm::dvec3 axis(x, y, z);
         axis = glm::normalize(axis);
 
-        ::glm::dmat4 matrix = ::glm::translate(::glm::dmat4(1.), center);
-        matrix = ::glm::rotate(matrix, angle, axis);
-        matrix = ::glm::translate(matrix, translation);
+        glm::dmat4 matrix = glm::translate(glm::dmat4(1.), center);
+        matrix = glm::rotate(matrix, angle, axis);
+        matrix = glm::translate(matrix, translation);
 
         sight::data::Matrix4::sptr mat = sight::data::Matrix4::New();
         geometry::data::setTF3DFromMatrix(*mat, matrix);
@@ -481,15 +481,18 @@ void helperTest::generateCharucoDict()
 
     int bits[32] = {4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7};
 
-    ::cv::Ptr< ::cv::aruco::Dictionary> generatedDict;
+    cv::Ptr<cv::aruco::Dictionary> generatedDict;
 
     //Test case 4x4_50
     for(int ii = 0 ; ii < 32 ; ++ii)
     {
-        ::cv::Ptr< ::cv::aruco::Dictionary> DictExpected =
-            ::cv::aruco::generateCustomDictionary(x[ii], bits[ii], ::cv::aruco::getPredefinedDictionary(ii / 2));
+        cv::Ptr<cv::aruco::Dictionary> DictExpected =
+            cv::aruco::generateCustomDictionary(x[ii], bits[ii], cv::aruco::getPredefinedDictionary(ii / 2));
 
-        CPPUNIT_ASSERT_NO_THROW(generatedDict = geometry::vision::helper::generateArucoDictionary(x[ii], 2, bits[ii]));
+        CPPUNIT_ASSERT_NO_THROW(
+            generatedDict =
+                geometry::vision::helper::generateArucoDictionary(static_cast<std::size_t>(x[ii]), 2, bits[ii])
+        );
 
         CPPUNIT_ASSERT_EQUAL_MESSAGE("markerSize are not equal", DictExpected->markerSize, generatedDict->markerSize);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
@@ -511,8 +514,8 @@ void helperTest::generateCharucoDict()
                 {
                     CPPUNIT_ASSERT_EQUAL_MESSAGE(
                         "Values of bytesList are not equal",
-                        DictExpected->bytesList.at< ::cv::Vec4b>(i, j)[k],
-                        generatedDict->bytesList.at< ::cv::Vec4b>(i, j)[k]
+                        DictExpected->bytesList.at<cv::Vec4b>(i, j)[k],
+                        generatedDict->bytesList.at<cv::Vec4b>(i, j)[k]
                     );
                 }
             }
@@ -526,11 +529,11 @@ void helperTest::chessboardDetectionTest()
 {
     const auto calibDataDir = utestData::Data::dir() / "sight" / "calibration";
     {
-        const ::cv::Mat chessRgb0 = readRGBImage((calibDataDir / "chessboardRGB0.tiff").string());
+        const cv::Mat chessRgb0 = readRGBImage((calibDataDir / "chessboardRGB0.tiff").string());
 
         CPPUNIT_ASSERT_EQUAL(false, chessRgb0.empty());
         CPPUNIT_ASSERT_EQUAL(3, chessRgb0.channels());
-        CPPUNIT_ASSERT_EQUAL(static_cast<size_t>(1), chessRgb0.elemSize1());
+        CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(1), chessRgb0.elemSize1());
 
         const sight::data::PointList::csptr detectedChess = geometry::vision::helper::detectChessboard(
             chessRgb0,
@@ -586,11 +589,11 @@ void helperTest::chessboardDetectionTest()
     }
 
     {
-        const ::cv::Mat chessRgb1 = readRGBImage((calibDataDir / "chessboardRGB1.tiff").string());
+        const cv::Mat chessRgb1 = readRGBImage((calibDataDir / "chessboardRGB1.tiff").string());
 
         CPPUNIT_ASSERT_EQUAL(false, chessRgb1.empty());
         CPPUNIT_ASSERT_EQUAL(3, chessRgb1.channels());
-        CPPUNIT_ASSERT_EQUAL(static_cast<size_t>(1), chessRgb1.elemSize1());
+        CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(1), chessRgb1.elemSize1());
 
         const sight::data::PointList::csptr detectedChess = geometry::vision::helper::detectChessboard(
             chessRgb1,
@@ -646,14 +649,14 @@ void helperTest::chessboardDetectionTest()
     }
 
     {
-        const ::cv::Mat chessGray = ::cv::imread(
+        const cv::Mat chessGray = cv::imread(
             (calibDataDir / "chessboardGray.tiff").string(),
-            ::cv::IMREAD_GRAYSCALE
+            cv::IMREAD_GRAYSCALE
         );
 
         CPPUNIT_ASSERT_EQUAL(false, chessGray.empty());
         CPPUNIT_ASSERT_EQUAL(1, chessGray.channels());
-        CPPUNIT_ASSERT_EQUAL(static_cast<size_t>(1), chessGray.elemSize1());
+        CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(1), chessGray.elemSize1());
 
         const sight::data::PointList::csptr detectedChess = geometry::vision::helper::detectChessboard(
             chessGray,
@@ -723,7 +726,7 @@ void helperTest::chessboardDetectionScaleTest()
 {
     const auto calibDataDir = utestData::Data::dir() / "sight" / "calibration";
 
-    const ::cv::Mat chessRgb0 = readRGBImage((calibDataDir / "chessboardRGB0.tiff").string());
+    const cv::Mat chessRgb0 = readRGBImage((calibDataDir / "chessboardRGB0.tiff").string());
 
     const sight::data::PointList::csptr detectedChessFullScale =
         geometry::vision::helper::detectChessboard(chessRgb0, 9, 6, 1.f);
