@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -38,6 +38,11 @@
 
 #include <filesystem>
 
+/**
+ * Do not mark `JPEGLS`, `JPIP` as incorrect.
+ * cspell:ignore JPEGLS JPIP
+ */
+
 namespace sight::io::dimse
 {
 
@@ -745,8 +750,8 @@ std::string SeriesEnquirer::findSOPInstanceUID(const std::string& _seriesInstanc
     dataset.putAndInsertOFStringArray(DCM_InstanceNumber, ss.str().c_str());
 
     OFList<QRResponse*> responses = this->sendFindRequest(dataset);
-    OFIterator<QRResponse*> it    = responses.begin();
-    std::string sopInstanceUID    = "";
+    OFListIterator(QRResponse*) it = responses.begin();
+    std::string sopInstanceUID = "";
     if(it != responses.end() && (*it)->m_dataset)
     {
         OFString sop;
@@ -996,8 +1001,8 @@ OFCondition SeriesEnquirer::handleSTORERequest(
         }
 
         // Find the instance UID.
-        OFString iname;
-        if(_incomingObject->findAndGetOFStringArray(DCM_SOPInstanceUID, iname).good())
+        OFString instanceID;
+        if(_incomingObject->findAndGetOFStringArray(DCM_SOPInstanceUID, instanceID).good())
         {
         }
 
@@ -1009,7 +1014,7 @@ OFCondition SeriesEnquirer::handleSTORERequest(
         }
 
         // Save the file in the specified folder (Create new meta header for gdcm reader).
-        std::string filePath = seriesPath.string() + iname.c_str();
+        std::string filePath = seriesPath.string() + instanceID.c_str();
         DcmFileFormat fileFormat(_incomingObject);
         fileFormat.saveFile(
             filePath.c_str(),
