@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,8 +26,6 @@
 #include <core/tools/random/Generator.hpp>
 #include <core/tools/System.hpp>
 
-#include <data/reflection/visitor/CompareObjects.hpp>
-
 #include <geometry/data/Mesh.hpp>
 
 #include <io/vtk/helper/Mesh.hpp>
@@ -54,7 +52,7 @@
 #include <filesystem>
 
 // Registers the fixture into the 'registry'
-CPPUNIT_TEST_SUITE_REGISTRATION(::sight::io::vtk::ut::MeshTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(sight::io::vtk::ut::MeshTest);
 
 namespace sight::io::vtk
 {
@@ -64,21 +62,6 @@ namespace ut
 
 using core::tools::random::safeRand;
 
-//-----------------------------------------------------------------------------
-
-void compare(data::Object::sptr objRef, data::Object::sptr objComp)
-{
-    data::reflection::visitor::CompareObjects visitor;
-    visitor.compare(objRef, objComp);
-    SPTR(data::reflection::visitor::CompareObjects::PropsMapType) props = visitor.getDifferences();
-    for(data::reflection::visitor::CompareObjects::PropsMapType::value_type prop : (*props))
-    {
-        SIGHT_ERROR("new object difference found : " << prop.first << " '" << prop.second << "'");
-    }
-
-    CPPUNIT_ASSERT_MESSAGE("Object Not equal", props->size() == 0);
-}
-
 //------------------------------------------------------------------------------
 
 void MeshTest::setUp()
@@ -106,8 +89,8 @@ void MeshTest::testMeshToVtk()
     source->Update();
     const vtkSmartPointer<vtkPolyData> poly_source = source->GetOutput();
 
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfPoints());
+    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::size_t>(0), mesh1->numCells());
+    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::size_t>(0), mesh1->numPoints());
 
     io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh1);
 
@@ -116,13 +99,13 @@ void MeshTest::testMeshToVtk()
     geometry::data::Mesh::colorizeMeshPoints(mesh1);
     geometry::data::Mesh::colorizeMeshCells(mesh1);
 
-    CPPUNIT_ASSERT(mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT(mesh1->getNumberOfPoints());
-    CPPUNIT_ASSERT(mesh1->hasPointNormals());
-    CPPUNIT_ASSERT(mesh1->hasCellNormals());
-    CPPUNIT_ASSERT(mesh1->hasPointColors());
-    CPPUNIT_ASSERT(mesh1->hasCellColors());
-    CPPUNIT_ASSERT(mesh1->hasPointTexCoords());
+    CPPUNIT_ASSERT(mesh1->numCells());
+    CPPUNIT_ASSERT(mesh1->numPoints());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::POINT_NORMALS>());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::CELL_NORMALS>());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::POINT_COLORS>());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::CELL_COLORS>());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::POINT_TEX_COORDS>());
 
     const vtkSmartPointer<vtkPolyData> vtkMesh = vtkSmartPointer<vtkPolyData>::New();
     io::vtk::helper::Mesh::toVTKMesh(mesh1, vtkMesh);
@@ -137,7 +120,7 @@ void MeshTest::testMeshToVtk()
     CPPUNIT_ASSERT(mesh2);
     io::vtk::helper::Mesh::fromVTKMesh(vtkMesh, mesh2);
 
-    compare(mesh1, mesh2);
+    CPPUNIT_ASSERT(*mesh1 == *mesh2);
 }
 
 //------------------------------------------------------------------------------
@@ -154,8 +137,8 @@ void MeshTest::testMeshToGrid()
     source->Update();
     const vtkSmartPointer<vtkPolyData> poly_source = source->GetOutput();
 
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfPoints());
+    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::size_t>(0), mesh1->numCells());
+    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::size_t>(0), mesh1->numPoints());
 
     io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh1);
 
@@ -164,13 +147,13 @@ void MeshTest::testMeshToGrid()
     geometry::data::Mesh::colorizeMeshPoints(mesh1);
     geometry::data::Mesh::colorizeMeshCells(mesh1);
 
-    CPPUNIT_ASSERT(mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT(mesh1->getNumberOfPoints());
-    CPPUNIT_ASSERT(mesh1->hasPointNormals());
-    CPPUNIT_ASSERT(mesh1->hasCellNormals());
-    CPPUNIT_ASSERT(mesh1->hasPointColors());
-    CPPUNIT_ASSERT(mesh1->hasCellColors());
-    CPPUNIT_ASSERT(mesh1->hasPointTexCoords());
+    CPPUNIT_ASSERT(mesh1->numCells());
+    CPPUNIT_ASSERT(mesh1->numPoints());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::POINT_NORMALS>());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::CELL_NORMALS>());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::POINT_COLORS>());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::CELL_COLORS>());
+    CPPUNIT_ASSERT(mesh1->has<data::Mesh::Attributes::POINT_TEX_COORDS>());
     const vtkSmartPointer<vtkUnstructuredGrid> vtkGrid = vtkSmartPointer<vtkUnstructuredGrid>::New();
     io::vtk::helper::Mesh::toVTKGrid(mesh1, vtkGrid);
     CPPUNIT_ASSERT(vtkGrid);
@@ -181,7 +164,7 @@ void MeshTest::testMeshToGrid()
     CPPUNIT_ASSERT(mesh2);
     io::vtk::helper::Mesh::fromVTKGrid(vtkGrid, mesh2);
 
-    compare(mesh1, mesh2);
+    CPPUNIT_ASSERT(*mesh1 == *mesh2);
 }
 
 //------------------------------------------------------------------------------
@@ -192,7 +175,7 @@ void MeshTest::testSyntheticMesh()
         const data::Mesh::sptr mesh1 = data::Mesh::New();
         utestData::generator::Mesh::generateTriangleQuadMesh(mesh1);
         geometry::data::Mesh::shakePoint(mesh1);
-        mesh1->adjustAllocatedMemory();
+        mesh1->shrinkToFit();
 
         const vtkSmartPointer<vtkPolyData> poly = vtkSmartPointer<vtkPolyData>::New();
         io::vtk::helper::Mesh::toVTKMesh(mesh1, poly);
@@ -201,7 +184,7 @@ void MeshTest::testSyntheticMesh()
         data::Mesh::sptr mesh2 = data::Mesh::New();
         io::vtk::helper::Mesh::fromVTKMesh(poly, mesh2);
 
-        compare(mesh1, mesh2);
+        CPPUNIT_ASSERT(*mesh1 == *mesh2);
     }
     {
         const data::Mesh::sptr mesh1 = data::Mesh::New();
@@ -211,7 +194,7 @@ void MeshTest::testSyntheticMesh()
         geometry::data::Mesh::colorizeMeshCells(mesh1);
         geometry::data::Mesh::generatePointNormals(mesh1);
         geometry::data::Mesh::generateCellNormals(mesh1);
-        mesh1->adjustAllocatedMemory();
+        mesh1->shrinkToFit();
 
         const vtkSmartPointer<vtkPolyData> poly = vtkSmartPointer<vtkPolyData>::New();
         io::vtk::helper::Mesh::toVTKMesh(mesh1, poly);
@@ -220,7 +203,7 @@ void MeshTest::testSyntheticMesh()
         data::Mesh::sptr mesh2 = data::Mesh::New();
         io::vtk::helper::Mesh::fromVTKMesh(poly, mesh2);
 
-        compare(mesh1, mesh2);
+        CPPUNIT_ASSERT(*mesh1 == *mesh2);
     }
 }
 
@@ -236,7 +219,7 @@ void MeshTest::testExportImportSyntheticMesh()
     geometry::data::Mesh::generatePointNormals(mesh1);
     geometry::data::Mesh::generateCellNormals(mesh1);
 
-    mesh1->adjustAllocatedMemory();
+    mesh1->shrinkToFit();
 
     const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
                                            / "testExportImportSyntheticMesh.vtk";
@@ -253,27 +236,27 @@ void MeshTest::testExportImportSyntheticMesh()
     reader->setFile(testFile);
     reader->read();
 
-    compare(mesh1, mesh2);
+    CPPUNIT_ASSERT(*mesh1 == *mesh2);
 
-    const bool suppr = std::filesystem::remove(testFile);
-    CPPUNIT_ASSERT(suppr);
+    const bool removed = std::filesystem::remove(testFile);
+    CPPUNIT_ASSERT(removed);
 }
 
 //------------------------------------------------------------------------------
 
 void MeshTest::testPointCloud()
 {
-    const data::Mesh::Size NB_POINTS = static_cast<data::Mesh::Size>(100 + safeRand() % 1000);
+    const data::Mesh::size_t NB_POINTS = static_cast<data::Mesh::size_t>(100 + safeRand() % 1000);
 
     const data::Mesh::sptr mesh1 = data::Mesh::New();
 
     mesh1->reserve(NB_POINTS, NB_POINTS, data::Mesh::CellType::POINT);
 
-    const auto dumpLock = mesh1->lock();
+    const auto dumpLock = mesh1->dump_lock();
 
-    for(data::Mesh::Size i = 0 ; i < NB_POINTS ; ++i)
+    for(data::Mesh::size_t i = 0 ; i < NB_POINTS ; ++i)
     {
-        data::Mesh::PointValueType point[3];
+        data::Mesh::position_t point[3];
         point[0] = (static_cast<float>(safeRand() % 1000) - 500.f) / 3.f;
         point[1] = (static_cast<float>(safeRand() % 1000) - 500.f) / 3.f;
         point[2] = (static_cast<float>(safeRand() % 1000) - 500.f) / 3.f;
@@ -288,208 +271,9 @@ void MeshTest::testPointCloud()
     const data::Mesh::sptr mesh2 = data::Mesh::New();
     io::vtk::helper::Mesh::fromVTKMesh(poly, mesh2);
 
-    CPPUNIT_ASSERT_EQUAL(NB_POINTS, mesh2->getNumberOfPoints());
-    CPPUNIT_ASSERT_EQUAL(NB_POINTS, mesh2->getNumberOfCells());
-    CPPUNIT_ASSERT_EQUAL(NB_POINTS, mesh2->getCellDataSize());
-    compare(mesh1, mesh2);
-}
-
-//------------------------------------------------------------------------------
-
-void MeshTest::testMeshUpdatePoints()
-{
-    const data::Mesh::sptr mesh1 = data::Mesh::New();
-    CPPUNIT_ASSERT(mesh1);
-
-    const vtkSmartPointer<vtkSphereSource> source = vtkSmartPointer<vtkSphereSource>::New();
-    source->SetThetaResolution(50);
-    source->SetPhiResolution(50);
-    source->SetRadius(2);
-    source->Update();
-    vtkSmartPointer<vtkPolyData> poly_source = source->GetOutput();
-
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfPoints());
-
-    io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh1);
-
-    // modify mesh vertex position
-    geometry::data::Mesh::shakePoint(mesh1);
-
-    io::vtk::helper::Mesh::updatePolyDataPoints(poly_source, mesh1);
-
-    const data::Mesh::sptr mesh2 = data::Mesh::New();
-    io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh2);
-
-    compare(mesh1, mesh2);
-}
-
-//------------------------------------------------------------------------------
-
-void MeshTest::testMeshUpdateColors()
-{
-    const data::Mesh::sptr mesh1 = data::Mesh::New();
-    CPPUNIT_ASSERT(mesh1);
-
-    const vtkSmartPointer<vtkSphereSource> source = vtkSmartPointer<vtkSphereSource>::New();
-    source->SetThetaResolution(50);
-    source->SetPhiResolution(50);
-    source->SetRadius(2);
-    source->Update();
-    vtkSmartPointer<vtkPolyData> poly_source = source->GetOutput();
-
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfPoints());
-
-    io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh1);
-
-    geometry::data::Mesh::colorizeMeshPoints(mesh1);
-    geometry::data::Mesh::colorizeMeshCells(mesh1);
-
-    io::vtk::helper::Mesh::updatePolyDataPointColor(poly_source, mesh1);
-    io::vtk::helper::Mesh::updatePolyDataCellColor(poly_source, mesh1);
-
-    const data::Mesh::sptr mesh2 = data::Mesh::New();
-    io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh2);
-
-    compare(mesh1, mesh2);
-}
-
-//------------------------------------------------------------------------------
-
-void MeshTest::testMeshUpdateNormals()
-{
-    const data::Mesh::sptr mesh1 = data::Mesh::New();
-    CPPUNIT_ASSERT(mesh1);
-
-    const vtkSmartPointer<vtkSphereSource> source = vtkSmartPointer<vtkSphereSource>::New();
-    source->SetThetaResolution(50);
-    source->SetPhiResolution(50);
-    source->SetRadius(2);
-    source->Update();
-    vtkSmartPointer<vtkPolyData> poly_source = source->GetOutput();
-
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfPoints());
-
-    io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh1);
-
-    geometry::data::Mesh::generatePointNormals(mesh1);
-    geometry::data::Mesh::generateCellNormals(mesh1);
-    geometry::data::Mesh::shakePointNormals(mesh1);
-    geometry::data::Mesh::shakeCellNormals(mesh1);
-
-    io::vtk::helper::Mesh::updatePolyDataPointNormals(poly_source, mesh1);
-    io::vtk::helper::Mesh::updatePolyDataCellNormals(poly_source, mesh1);
-
-    const data::Mesh::sptr mesh2 = data::Mesh::New();
-    io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh2);
-
-    compare(mesh1, mesh2);
-}
-
-//------------------------------------------------------------------------------
-
-void MeshTest::testGridUpdatePoints()
-{
-    const data::Mesh::sptr mesh1 = data::Mesh::New();
-    CPPUNIT_ASSERT(mesh1);
-
-    const vtkSmartPointer<vtkSphereSource> source = vtkSmartPointer<vtkSphereSource>::New();
-    source->SetThetaResolution(50);
-    source->SetPhiResolution(50);
-    source->SetRadius(2);
-    source->Update();
-    const vtkSmartPointer<vtkPolyData> poly_source = source->GetOutput();
-
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfPoints());
-
-    io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh1);
-
-    vtkSmartPointer<vtkUnstructuredGrid> vtkGrid = vtkSmartPointer<vtkUnstructuredGrid>::New();
-    io::vtk::helper::Mesh::toVTKGrid(mesh1, vtkGrid);
-    CPPUNIT_ASSERT(vtkGrid);
-
-    // modify mesh vertex position
-    geometry::data::Mesh::shakePoint(mesh1);
-    io::vtk::helper::Mesh::updateGridPoints(vtkGrid, mesh1);
-
-    const data::Mesh::sptr mesh2 = data::Mesh::New();
-    io::vtk::helper::Mesh::fromVTKGrid(vtkGrid, mesh2);
-
-    compare(mesh1, mesh2);
-}
-
-//------------------------------------------------------------------------------
-
-void MeshTest::testGridUpdateColors()
-{
-    const data::Mesh::sptr mesh1 = data::Mesh::New();
-    CPPUNIT_ASSERT(mesh1);
-
-    const vtkSmartPointer<vtkSphereSource> source = vtkSmartPointer<vtkSphereSource>::New();
-    source->SetThetaResolution(50);
-    source->SetPhiResolution(50);
-    source->SetRadius(2);
-    source->Update();
-    const vtkSmartPointer<vtkPolyData> poly_source = source->GetOutput();
-
-    io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh1);
-
-    vtkSmartPointer<vtkUnstructuredGrid> vtkGrid = vtkSmartPointer<vtkUnstructuredGrid>::New();
-    io::vtk::helper::Mesh::toVTKGrid(mesh1, vtkGrid);
-    CPPUNIT_ASSERT(vtkGrid);
-
-    geometry::data::Mesh::colorizeMeshPoints(mesh1);
-    geometry::data::Mesh::colorizeMeshCells(mesh1);
-
-    io::vtk::helper::Mesh::updateGridPointColor(vtkGrid, mesh1);
-    io::vtk::helper::Mesh::updateGridCellColor(vtkGrid, mesh1);
-
-    const data::Mesh::sptr mesh2 = data::Mesh::New();
-    io::vtk::helper::Mesh::fromVTKGrid(vtkGrid, mesh2);
-
-    compare(mesh1, mesh2);
-}
-
-//------------------------------------------------------------------------------
-
-void MeshTest::testGridUpdateNormals()
-{
-    const data::Mesh::sptr mesh1 = data::Mesh::New();
-    CPPUNIT_ASSERT(mesh1);
-
-    const vtkSmartPointer<vtkSphereSource> source = vtkSmartPointer<vtkSphereSource>::New();
-    source->SetThetaResolution(50);
-    source->SetPhiResolution(50);
-    source->SetRadius(2);
-    source->Update();
-    const vtkSmartPointer<vtkPolyData> poly_source = source->GetOutput();
-
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT_EQUAL(static_cast<data::Mesh::Size>(0), mesh1->getNumberOfPoints());
-
-    io::vtk::helper::Mesh::fromVTKMesh(poly_source, mesh1);
-
-    geometry::data::Mesh::generatePointNormals(mesh1);
-    geometry::data::Mesh::generateCellNormals(mesh1);
-
-    CPPUNIT_ASSERT(mesh1->getNumberOfCells());
-    CPPUNIT_ASSERT(mesh1->getNumberOfPoints());
-
-    vtkSmartPointer<vtkUnstructuredGrid> vtkGrid = vtkSmartPointer<vtkUnstructuredGrid>::New();
-    io::vtk::helper::Mesh::toVTKGrid(mesh1, vtkGrid);
-    CPPUNIT_ASSERT(vtkGrid);
-
-    io::vtk::helper::Mesh::updateGridPoints(vtkGrid, mesh1);
-    io::vtk::helper::Mesh::updateGridPointNormals(vtkGrid, mesh1);
-    io::vtk::helper::Mesh::updateGridCellNormals(vtkGrid, mesh1);
-
-    const data::Mesh::sptr mesh2 = data::Mesh::New();
-    io::vtk::helper::Mesh::fromVTKGrid(vtkGrid, mesh2);
-
-    compare(mesh1, mesh2);
+    CPPUNIT_ASSERT_EQUAL(NB_POINTS, mesh2->numPoints());
+    CPPUNIT_ASSERT_EQUAL(NB_POINTS, mesh2->numCells());
+    CPPUNIT_ASSERT(*mesh1 == *mesh2);
 }
 
 //------------------------------------------------------------------------------
@@ -504,15 +288,15 @@ void MeshTest::testReadVtkFile()
 
     data::Mesh::sptr mesh = data::Mesh::New();
 
-    io::vtk::MeshReader::sptr vtkReader = io::vtk::MeshReader::New();
+    io::vtk::MeshReader::sptr vtk_reader = io::vtk::MeshReader::New();
 
-    vtkReader->setObject(mesh);
-    vtkReader->setFile(testFile);
+    vtk_reader->setObject(mesh);
+    vtk_reader->setFile(testFile);
 
-    CPPUNIT_ASSERT_NO_THROW(vtkReader->read());
+    CPPUNIT_ASSERT_NO_THROW(vtk_reader->read());
 
-    CPPUNIT_ASSERT(mesh->getNumberOfCells() == 720);
-    CPPUNIT_ASSERT(mesh->getNumberOfPoints() == 362);
+    CPPUNIT_ASSERT(mesh->numCells() == 720);
+    CPPUNIT_ASSERT(mesh->numPoints() == 362);
 }
 
 //------------------------------------------------------------------------------
@@ -527,15 +311,15 @@ void MeshTest::testReadVtpFile()
 
     data::Mesh::sptr mesh = data::Mesh::New();
 
-    io::vtk::VtpMeshReader::sptr vtkReader = io::vtk::VtpMeshReader::New();
+    io::vtk::VtpMeshReader::sptr vtk_reader = io::vtk::VtpMeshReader::New();
 
-    vtkReader->setObject(mesh);
-    vtkReader->setFile(testFile);
+    vtk_reader->setObject(mesh);
+    vtk_reader->setFile(testFile);
 
-    CPPUNIT_ASSERT_NO_THROW(vtkReader->read());
+    CPPUNIT_ASSERT_NO_THROW(vtk_reader->read());
 
-    CPPUNIT_ASSERT(mesh->getNumberOfCells() == 720);
-    CPPUNIT_ASSERT(mesh->getNumberOfPoints() == 362);
+    CPPUNIT_ASSERT(mesh->numCells() == 720);
+    CPPUNIT_ASSERT(mesh->numPoints() == 362);
 }
 
 //------------------------------------------------------------------------------
@@ -550,15 +334,15 @@ void MeshTest::testReadObjFile()
 
     data::Mesh::sptr mesh = data::Mesh::New();
 
-    io::vtk::ObjMeshReader::sptr vtkReader = io::vtk::ObjMeshReader::New();
+    io::vtk::ObjMeshReader::sptr vtk_reader = io::vtk::ObjMeshReader::New();
 
-    vtkReader->setObject(mesh);
-    vtkReader->setFile(testFile);
+    vtk_reader->setObject(mesh);
+    vtk_reader->setFile(testFile);
 
-    CPPUNIT_ASSERT_NO_THROW(vtkReader->read());
+    CPPUNIT_ASSERT_NO_THROW(vtk_reader->read());
 
-    CPPUNIT_ASSERT(mesh->getNumberOfCells() == 720);
-    CPPUNIT_ASSERT(mesh->getNumberOfPoints() == 362);
+    CPPUNIT_ASSERT(mesh->numCells() == 720);
+    CPPUNIT_ASSERT(mesh->numPoints() == 362);
 }
 
 //------------------------------------------------------------------------------
@@ -573,15 +357,15 @@ void MeshTest::testReadPlyFile()
 
     data::Mesh::sptr mesh = data::Mesh::New();
 
-    io::vtk::PlyMeshReader::sptr vtkReader = io::vtk::PlyMeshReader::New();
+    io::vtk::PlyMeshReader::sptr vtk_reader = io::vtk::PlyMeshReader::New();
 
-    vtkReader->setObject(mesh);
-    vtkReader->setFile(testFile);
+    vtk_reader->setObject(mesh);
+    vtk_reader->setFile(testFile);
 
-    CPPUNIT_ASSERT_NO_THROW(vtkReader->read());
+    CPPUNIT_ASSERT_NO_THROW(vtk_reader->read());
 
-    CPPUNIT_ASSERT(mesh->getNumberOfCells() == 720);
-    CPPUNIT_ASSERT(mesh->getNumberOfPoints() == 362);
+    CPPUNIT_ASSERT(mesh->numCells() == 720);
+    CPPUNIT_ASSERT(mesh->numPoints() == 362);
 }
 
 //------------------------------------------------------------------------------
@@ -596,15 +380,15 @@ void MeshTest::testReadStlFile()
 
     data::Mesh::sptr mesh = data::Mesh::New();
 
-    io::vtk::StlMeshReader::sptr vtkReader = io::vtk::StlMeshReader::New();
+    io::vtk::StlMeshReader::sptr vtk_reader = io::vtk::StlMeshReader::New();
 
-    vtkReader->setObject(mesh);
-    vtkReader->setFile(testFile);
+    vtk_reader->setObject(mesh);
+    vtk_reader->setFile(testFile);
 
-    CPPUNIT_ASSERT_NO_THROW(vtkReader->read());
+    CPPUNIT_ASSERT_NO_THROW(vtk_reader->read());
 
-    CPPUNIT_ASSERT(mesh->getNumberOfCells() == 720);
-    CPPUNIT_ASSERT(mesh->getNumberOfPoints() == 362);
+    CPPUNIT_ASSERT(mesh->numCells() == 720);
+    CPPUNIT_ASSERT(mesh->numPoints() == 362);
 }
 
 //------------------------------------------------------------------------------
@@ -619,7 +403,7 @@ void MeshTest::testWriteVtkFile()
     geometry::data::Mesh::generatePointNormals(mesh1);
     geometry::data::Mesh::generateCellNormals(mesh1);
 
-    mesh1->adjustAllocatedMemory();
+    mesh1->shrinkToFit();
 
     const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
                                            / "vtkTestMesh.vtk";
@@ -643,7 +427,7 @@ void MeshTest::testWriteVtpFile()
     geometry::data::Mesh::generatePointNormals(mesh1);
     geometry::data::Mesh::generateCellNormals(mesh1);
 
-    mesh1->adjustAllocatedMemory();
+    mesh1->shrinkToFit();
 
     const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
                                            / "vtpTestMesh.vtp";
@@ -667,7 +451,7 @@ void MeshTest::testWriteObjFile()
     geometry::data::Mesh::generatePointNormals(mesh1);
     geometry::data::Mesh::generateCellNormals(mesh1);
 
-    mesh1->adjustAllocatedMemory();
+    mesh1->shrinkToFit();
 
     const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
                                            / "objTestMesh.obj";
@@ -691,7 +475,7 @@ void MeshTest::testWritePlyFile()
     geometry::data::Mesh::generatePointNormals(mesh1);
     geometry::data::Mesh::generateCellNormals(mesh1);
 
-    mesh1->adjustAllocatedMemory();
+    mesh1->shrinkToFit();
 
     const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
                                            / "plyTestMesh.ply";
@@ -715,7 +499,7 @@ void MeshTest::testWriteStlFile()
     geometry::data::Mesh::generatePointNormals(mesh1);
     geometry::data::Mesh::generateCellNormals(mesh1);
 
-    mesh1->adjustAllocatedMemory();
+    mesh1->shrinkToFit();
 
     const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
                                            / "stlTestMesh.stl";
