@@ -40,7 +40,6 @@ class SeriesDBTest : public CPPUNIT_NS::TestFixture
 {
 CPPUNIT_TEST_SUITE(SeriesDBTest);
 CPPUNIT_TEST(testImportSeriesDB);
-CPPUNIT_TEST(testLazyImportSeriesDB);
 CPPUNIT_TEST_SUITE_END();
 
 public:
@@ -50,7 +49,6 @@ public:
     void tearDown();
 
     void testImportSeriesDB();
-    void testLazyImportSeriesDB();
 };
 
 } // namespace ut
