@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2022 IRCAD France
  * Copyright (C) 2014-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -19,7 +19,7 @@
  * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
  *
  ***********************************************************************/
-
+// cspell: disable
 /******************************************************************************************
    MOC - Minimal Ogre Collision v 1.0
    The MIT License
@@ -48,7 +48,7 @@
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
    THE SOFTWARE.
 ******************************************************************************************/
-
+// cspell: enable
 #include "viz/scene3d/collisionTools/CollisionTools.hpp"
 
 #include "viz/scene3d/factory/R2VBRenderable.hpp"
@@ -60,11 +60,11 @@
 namespace sight::viz::scene3d
 {
 
-CollisionTools::CollisionTools(::Ogre::SceneManager* _sceneMgr, std::uint32_t _queryMask)
+CollisionTools::CollisionTools(Ogre::SceneManager* _sceneMgr, std::uint32_t _queryMask)
 {
     mSceneMgr = _sceneMgr;
 
-    mRaySceneQuery = mSceneMgr->createRayQuery(::Ogre::Ray(), _queryMask);
+    mRaySceneQuery = mSceneMgr->createRayQuery(Ogre::Ray(), _queryMask);
     if(nullptr == mRaySceneQuery)
     {
         // LOG_ERROR << "Failed to create Ogre::RaySceneQuery instance" << ENDLOG;
@@ -116,15 +116,15 @@ bool CollisionTools::collidesWithEntity(
 //------------------------------------------------------------------------------
 
 std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::raycastFromCamera(
-    ::Ogre::RenderWindow* _rw,
+    Ogre::RenderWindow* _rw,
     Ogre::Camera* _camera,
     const Ogre::Vector2& _mousecoords,
     const Ogre::uint32 _queryMask
 )
 {
     // Create the ray to test
-    Ogre::Real tx = _mousecoords.x / static_cast< ::Ogre::Real>(_rw->getWidth());
-    Ogre::Real ty = _mousecoords.y / static_cast< ::Ogre::Real>(_rw->getHeight());
+    Ogre::Real tx = _mousecoords.x / static_cast<Ogre::Real>(_rw->getWidth());
+    Ogre::Real ty = _mousecoords.y / static_cast<Ogre::Real>(_rw->getHeight());
     Ogre::Ray ray = _camera->getCameraToViewportRay(tx, ty);
 
     return raycast(ray, _queryMask);
@@ -184,7 +184,7 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
     closestDistance = -1.0f;
     Ogre::Vector3 closestResult;
     Ogre::RaySceneQueryResult& queryResult = mRaySceneQuery->getLastResults();
-    for(size_t qrIdx = 0 ; qrIdx < queryResult.size() ; qrIdx++)
+    for(std::size_t qrIdx = 0 ; qrIdx < queryResult.size() ; qrIdx++)
     {
         // Stop checking if we have found a raycast hit that is closer
         // than all remaining entities.
@@ -195,7 +195,7 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
         }
 
         // Get the entity to check.
-        Ogre::MovableObject* const pentity = queryResult[qrIdx].movable;
+        Ogre::MovableObject* const entity = queryResult[qrIdx].movable;
 
         const bool isEntity = queryResult[qrIdx].movable->getMovableType().compare("Entity") == 0;
         const bool isR2VB   = queryResult[qrIdx].movable->getMovableType().compare(
@@ -203,22 +203,22 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                               ) == 0;
 
         // Only check this result if its a hit against an entity.
-        if((pentity != nullptr) && (isEntity || isR2VB))
+        if((entity != nullptr) && (isEntity || isR2VB))
         {
-            if(!pentity->isVisible())
+            if(!entity->isVisible())
             {
                 continue;
             }
 
-            const Ogre::Vector3 position       = pentity->getParentNode()->_getDerivedPosition();
-            const Ogre::Quaternion orientation = pentity->getParentNode()->_getDerivedOrientation();
-            const Ogre::Vector3 scale          = pentity->getParentNode()->_getDerivedScale();
+            const Ogre::Vector3 position       = entity->getParentNode()->_getDerivedPosition();
+            const Ogre::Quaternion orientation = entity->getParentNode()->_getDerivedOrientation();
+            const Ogre::Vector3 scale          = entity->getParentNode()->_getDerivedScale();
 
-            const ::Ogre::MeshPtr mesh = isEntity
-                                         ? static_cast< ::Ogre::Entity*>(pentity)->getMesh()
-                                         : static_cast<viz::scene3d::R2VBRenderable*>(pentity)->getMesh();
+            const Ogre::MeshPtr mesh = isEntity
+                                       ? static_cast<Ogre::Entity*>(entity)->getMesh()
+                                       : static_cast<viz::scene3d::R2VBRenderable*>(entity)->getMesh();
 
-            std::vector< ::Ogre::Vector3> vertices;
+            std::vector<Ogre::Vector3> vertices;
             bool addedShared = false;
 
             for(const Ogre::SubMesh* const submesh : mesh->getSubMeshes())
@@ -240,27 +240,28 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                     const Ogre::VertexData* vertexData =
                         submesh->useSharedVertices ? mesh->sharedVertexData : submesh->vertexData;
                     const Ogre::VertexElement* const posElem =
-                        vertexData->vertexDeclaration->findElementBySemantic(::Ogre::VES_POSITION);
-                    const Ogre::HardwareVertexBufferSharedPtr vbuf = vertexData->vertexBufferBinding->getBuffer(
-                        posElem->getSource()
-                    );
+                        vertexData->vertexDeclaration->findElementBySemantic(Ogre::VES_POSITION);
+                    const Ogre::HardwareVertexBufferSharedPtr vertex_buffer =
+                        vertexData->vertexBufferBinding->getBuffer(
+                            posElem->getSource()
+                        );
 
                     unsigned char* vertex =
-                        static_cast<unsigned char*>(vbuf->lock(::Ogre::HardwareBuffer::HBL_READ_ONLY));
+                        static_cast<unsigned char*>(vertex_buffer->lock(Ogre::HardwareBuffer::HBL_READ_ONLY));
                     float* pReal;
 
-                    for(size_t j = 0 ; j < vertexData->vertexCount ; ++j, vertex += vbuf->getVertexSize())
+                    for(std::size_t j = 0 ; j < vertexData->vertexCount ; ++j, vertex += vertex_buffer->getVertexSize())
                     {
                         posElem->baseVertexPointerToElement(vertex, &pReal);
                         Ogre::Vector3 pt(pReal[0], pReal[1], pReal[2]);
                         vertices[j] = (orientation * (pt * scale)) + position;
                     }
 
-                    vbuf->unlock();
+                    vertex_buffer->unlock();
                 }
 
                 // Retrieve the index buffer to loop over vertices.
-                std::vector< ::Ogre::uint32> indices;
+                std::vector<Ogre::uint32> indices;
                 {
                     const Ogre::IndexData* const indexData        = submesh->indexData;
                     const Ogre::HardwareIndexBufferSharedPtr ibuf = indexData->indexBuffer;
@@ -268,10 +269,10 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                     // Billboars do not define an entity, they do not contain any index buffer.
                     if(ibuf != nullptr)
                     {
-                        const bool use32bitindexes = (ibuf->getType() == ::Ogre::HardwareIndexBuffer::IT_32BIT);
+                        const bool use32bitindexes = (ibuf->getType() == Ogre::HardwareIndexBuffer::IT_32BIT);
 
-                        const ::Ogre::uint32* const pLong =
-                            static_cast<const ::Ogre::uint32*>(ibuf->lock(::Ogre::HardwareBuffer::HBL_READ_ONLY));
+                        const Ogre::uint32* const pLong =
+                            static_cast<const Ogre::uint32*>(ibuf->lock(Ogre::HardwareBuffer::HBL_READ_ONLY));
                         const unsigned short* const pShort = reinterpret_cast<const unsigned short*>(pLong);
 
                         indices.resize(indexData->indexCount);
@@ -279,14 +280,14 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                         // Iterate over index buffer.
                         if(use32bitindexes)
                         {
-                            for(size_t k = 0 ; k < indexData->indexCount ; ++k)
+                            for(std::size_t k = 0 ; k < indexData->indexCount ; ++k)
                             {
                                 indices[k] = pLong[k];
                             }
                         }
                         else
                         {
-                            for(size_t k = 0 ; k < indexData->indexCount ; ++k)
+                            for(std::size_t k = 0 ; k < indexData->indexCount ; ++k)
                             {
                                 indices[k] = static_cast<Ogre::uint32>(pShort[k]);
                             }
@@ -297,7 +298,7 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                 }
 
                 // Retrieve the material to check the culling mode.
-                const ::Ogre::MaterialPtr material = ::Ogre::MaterialManager::getSingletonPtr()->getByName(
+                const Ogre::MaterialPtr material = Ogre::MaterialManager::getSingletonPtr()->getByName(
                     submesh->getMaterialName()
                 );
                 bool positiveSide = true;
@@ -313,26 +314,26 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                         "'" + material->getName() + "' technique '" + tech->getName() + "' does not define any passes.",
                         passes.size() > 0
                     );
-                    for(const ::Ogre::Pass* pass : passes)
+                    for(const Ogre::Pass* pass : passes)
                     {
-                        const ::Ogre::CullingMode cullingMode = pass->getCullingMode();
+                        const Ogre::CullingMode cullingMode = pass->getCullingMode();
                         switch(cullingMode)
                         {
-                            case ::Ogre::CULL_NONE:
+                            case Ogre::CULL_NONE:
                                 positiveSide = true;
                                 negativeSide = true;
                                 break;
 
-                            case ::Ogre::CULL_CLOCKWISE:
+                            case Ogre::CULL_CLOCKWISE:
                                 positiveSide = true;
                                 break;
 
-                            case ::Ogre::CULL_ANTICLOCKWISE:
+                            case Ogre::CULL_ANTICLOCKWISE:
                                 negativeSide = true;
                                 break;
 
                             default:
-                                SIGHT_ERROR("Unsuported culling mode");
+                                SIGHT_ERROR("Unsupported culling mode");
                                 break;
                         }
                     }
@@ -343,29 +344,29 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                 switch(submesh->operationType)
                 {
                     // Points list is used for billboard.
-                    case ::Ogre::RenderOperation::OT_POINT_LIST:
+                    case Ogre::RenderOperation::OT_POINT_LIST:
                     {
                         // We do not have faces, we simply check all vertices and compute the distance from the picked
                         // point
-                        const ::Ogre::Camera* const camera = mSceneMgr->getCamera(
+                        const Ogre::Camera* const camera = mSceneMgr->getCamera(
                             viz::scene3d::Layer::s_DEFAULT_CAMERA_NAME
                         );
-                        const ::Ogre::Matrix4 viewMatrix = camera->getViewMatrix();
-                        const ::Ogre::Matrix4 projMatrix = camera->getProjectionMatrixWithRSDepth();
+                        const Ogre::Matrix4 viewMatrix = camera->getViewMatrix();
+                        const Ogre::Matrix4 projMatrix = camera->getProjectionMatrixWithRSDepth();
 
-                        const ::Ogre::Matrix4 viewProjMatrix = projMatrix * viewMatrix;
+                        const Ogre::Matrix4 viewProjMatrix = projMatrix * viewMatrix;
 
-                        const ::Ogre::Vector3 resPointWVP = viewProjMatrix * _ray.getPoint(queryResult[qrIdx].distance);
-                        const ::Ogre::Vector2 resPointSS  = (resPointWVP.xy() / 2.f) + 0.5f;
+                        const Ogre::Vector3 resPointWVP = viewProjMatrix * _ray.getPoint(queryResult[qrIdx].distance);
+                        const Ogre::Vector2 resPointSS  = (resPointWVP.xy() / 2.f) + 0.5f;
 
-                        static const ::Ogre::Real s_TOLERANCE = 0.02f;
+                        static const Ogre::Real s_TOLERANCE = 0.02f;
 
                         if(indices.size() > 0)
                         {
-                            for(size_t i = 0 ; i < indices.size() ; ++i)
+                            for(std::size_t i = 0 ; i < indices.size() ; ++i)
                             {
-                                const ::Ogre::Vector3 pointWVP = viewProjMatrix * vertices[indices[i]];
-                                const ::Ogre::Vector2 pointSS  = (pointWVP.xy() / 2.f) + 0.5f;
+                                const Ogre::Vector3 pointWVP = viewProjMatrix * vertices[indices[i]];
+                                const Ogre::Vector2 pointSS  = (pointWVP.xy() / 2.f) + 0.5f;
 
                                 if(((closestDistance < 0.0f) || (queryResult[qrIdx].distance < closestDistance))
                                    && resPointSS.distance(pointSS) < s_TOLERANCE)
@@ -377,10 +378,10 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                         }
                         else
                         {
-                            for(size_t i = 0 ; i < vertices.size() ; ++i)
+                            for(std::size_t i = 0 ; i < vertices.size() ; ++i)
                             {
-                                const ::Ogre::Vector3 pointWVP = viewProjMatrix * vertices[i];
-                                const ::Ogre::Vector2 pointSS  = (pointWVP.xy() / 2.f) + 0.5f;
+                                const Ogre::Vector3 pointWVP = viewProjMatrix * vertices[i];
+                                const Ogre::Vector2 pointSS  = (pointWVP.xy() / 2.f) + 0.5f;
 
                                 if(((closestDistance < 0.0f) || (queryResult[qrIdx].distance < closestDistance))
                                    && resPointSS.distance(pointSS) < s_TOLERANCE)
@@ -395,10 +396,10 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                     }
 
                     // Lines list is used to represent a quad.
-                    case ::Ogre::RenderOperation::OT_LINE_LIST:
+                    case Ogre::RenderOperation::OT_LINE_LIST:
                         if(indices.size() > 0)
                         {
-                            for(size_t i = 0 ; i < indices.size() ; i += 4)
+                            for(std::size_t i = 0 ; i < indices.size() ; i += 4)
                             {
                                 const auto firstHit = intersect(
                                     _ray,
@@ -433,7 +434,7 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                         }
                         else
                         {
-                            for(size_t i = 0 ; i < vertices.size() ; i += 4)
+                            for(std::size_t i = 0 ; i < vertices.size() ; i += 4)
                             {
                                 const auto firstHit = intersect(
                                     _ray,
@@ -470,10 +471,10 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                         break;
 
                     // Triangles list is simply a list of triangles.
-                    case ::Ogre::RenderOperation::OT_TRIANGLE_LIST:
+                    case Ogre::RenderOperation::OT_TRIANGLE_LIST:
                         if(indices.size() > 0)
                         {
-                            for(size_t i = 0 ; i < indices.size() ; i += 3)
+                            for(std::size_t i = 0 ; i < indices.size() ; i += 3)
                             {
                                 const auto firstHit = intersect(
                                     _ray,
@@ -493,7 +494,7 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                         }
                         else
                         {
-                            for(size_t i = 0 ; i < vertices.size() ; i += 3)
+                            for(std::size_t i = 0 ; i < vertices.size() ; i += 3)
                             {
                                 const auto firstHit = intersect(
                                     _ray,
@@ -515,13 +516,13 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
                         break;
 
                     default:
-                        SIGHT_ERROR("Unsuported operation type");
+                        SIGHT_ERROR("Unsupported operation type");
                         break;
                 }
 
                 if(newClosestFound)
                 {
-                    target        = pentity;
+                    target        = entity;
                     closestResult = _ray.getPoint(closestDistance);
                 }
             }
@@ -535,10 +536,10 @@ std::tuple<bool, Ogre::Vector3, Ogre::MovableObject*, float> CollisionTools::ray
 //------------------------------------------------------------------------------
 
 std::pair<bool, float> CollisionTools::intersect(
-    const ::Ogre::Ray& _ray,
-    const ::Ogre::Vector3& _a,
-    const ::Ogre::Vector3& _b,
-    const ::Ogre::Vector3& _c,
+    const Ogre::Ray& _ray,
+    const Ogre::Vector3& _a,
+    const Ogre::Vector3& _b,
+    const Ogre::Vector3& _c,
     const float _closestDistance,
     bool _positiveSide,
     bool _negativeSide
