@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2022 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -36,6 +36,11 @@
 
 #include <regex>
 
+/**
+ * Do not mark `SAMPLER1DSHADOW`, `SAMPLER2DSHADOW` as incorrect.
+ * cspell:ignore SAMPLER1DSHADOW SAMPLER2DSHADOW
+ */
+
 namespace sight::viz::scene3d
 {
 
@@ -53,12 +58,11 @@ static const std::regex s_LIGHT_PARAM_REGEX("u_f[2-4]?(NumLights|Light(Ambient|D
 
 static const std::string s_AMBIENT       = "Ambient";
 static const std::string s_FLAT          = "Flat";
-static const std::string s_GOURAUD       = "Gouraud";
 static const std::string s_PIXELLIGHTING = "PixelLit";
 
 //-----------------------------------------------------------------------------
 
-bool Shading::isColorTechnique(const ::Ogre::Technique& _tech)
+bool Shading::isColorTechnique(const Ogre::Technique& _tech)
 {
     const std::string& name = _tech.getName();
     const std::regex regexDualPeelInit("Dual.*/peelInit.*");
@@ -72,7 +76,7 @@ bool Shading::isColorTechnique(const ::Ogre::Technique& _tech)
 
 //-----------------------------------------------------------------------------
 
-bool Shading::isPeelTechnique(const ::Ogre::Technique& _tech)
+bool Shading::isPeelTechnique(const Ogre::Technique& _tech)
 {
     const std::string& name = _tech.getName();
     const bool peelTech     = std::regex_match(name, s_PEEL_REGEX);
@@ -82,7 +86,7 @@ bool Shading::isPeelTechnique(const ::Ogre::Technique& _tech)
 
 //-----------------------------------------------------------------------------
 
-bool Shading::isGeometricTechnique(const ::Ogre::Technique& _tech)
+bool Shading::isGeometricTechnique(const Ogre::Technique& _tech)
 {
     const std::string& name = _tech.getName();
 
@@ -95,7 +99,7 @@ bool Shading::isGeometricTechnique(const ::Ogre::Technique& _tech)
 
 //-----------------------------------------------------------------------------
 
-bool Shading::isDepthOnlyTechnique(const ::Ogre::Technique& _tech)
+bool Shading::isDepthOnlyTechnique(const Ogre::Technique& _tech)
 {
     const std::string& name = _tech.getName();
     const bool depth        = std::regex_match(name, s_DEPTH_MAP_REGEX);
@@ -118,10 +122,6 @@ std::string Shading::getPermutation(data::Material::ShadingType _mode, bool _dif
             suffix = s_FLAT;
             break;
 
-        case data::Material::GOURAUD:
-            suffix = s_GOURAUD;
-            break;
-
         case data::Material::PHONG:
             suffix = s_PIXELLIGHTING;
             break;
@@ -142,50 +142,6 @@ std::string Shading::getPermutation(data::Material::ShadingType _mode, bool _dif
 
 //-----------------------------------------------------------------------------
 
-std::string Shading::getR2VBGeometryProgramName(
-    data::Mesh::CellTypesEnum _primitiveType,
-    bool _diffuseTexture,
-    bool _vertexColor,
-    bool _hasPrimitiveColor
-)
-{
-    std::string suffix;
-
-    if(_primitiveType == data::Mesh::QUAD)
-    {
-        suffix = "Quad";
-    }
-    else if(_primitiveType == data::Mesh::TETRA)
-    {
-        suffix = "Tetra";
-    }
-    else
-    {
-        suffix = "Triangles";
-    }
-
-    if(_vertexColor)
-    {
-        suffix += "+VT";
-    }
-
-    if(_diffuseTexture)
-    {
-        suffix += "+DfsTex";
-    }
-
-    if(_hasPrimitiveColor)
-    {
-        suffix += "+PPColor";
-    }
-
-    const std::string name = "R2VB/" + suffix + "_GP";
-
-    return name;
-}
-
-//-----------------------------------------------------------------------------
-
 std::string Shading::getR2VBGeometryProgramName(
     data::Mesh::CellType _primitiveType,
     bool _diffuseTexture,
@@ -239,8 +195,7 @@ std::string Shading::setPermutationInProgramName(const std::string& _name, const
     prgName = std::regex_replace(_name, regexConcat, "$1");
 
     // Replace the shading technique
-    static const std::regex regexShading("(" + s_AMBIENT + ")|(" + s_FLAT + ")|(" + s_GOURAUD + ")|("
-                                         + s_PIXELLIGHTING + ")");
+    static const std::regex regexShading("(" + s_AMBIENT + ")|(" + s_FLAT + ")|(" + s_PIXELLIGHTING + ")");
     prgName = std::regex_replace(prgName, regexShading, _permutation);
 
     return prgName;
@@ -261,38 +216,38 @@ std::string Shading::setTechniqueInProgramName(const std::string& _name, const s
 
 //------------------------------------------------------------------------------
 
-Shading::ShaderConstantsType Shading::findMaterialConstants(::Ogre::Material& _material)
+Shading::ShaderConstantsType Shading::findMaterialConstants(Ogre::Material& _material)
 {
     ShaderConstantsType constants;
 
     // Only work on the first technique
-    ::Ogre::Pass* pass = _material.getTechnique(0)->getPass(0);
+    Ogre::Pass* pass = _material.getTechnique(0)->getPass(0);
 
     // If the material is programmable (ie contains shader programs) create associated ShaderParameter adaptor
     // with the given data::Object ID
     if(pass->isProgrammable())
     {
-        ::Ogre::GpuProgramParametersSharedPtr params;
+        Ogre::GpuProgramParametersSharedPtr params;
 
         // Getting params for each program type
         if(pass->hasVertexProgram())
         {
             params = pass->getVertexProgramParameters();
-            auto vpConstants = findShaderConstants(params, ::Ogre::GPT_VERTEX_PROGRAM);
+            auto vpConstants = findShaderConstants(params, Ogre::GPT_VERTEX_PROGRAM);
             std::move(vpConstants.begin(), vpConstants.end(), std::inserter(constants, constants.begin()));
         }
 
         if(pass->hasFragmentProgram())
         {
             params = pass->getFragmentProgramParameters();
-            auto fpConstants = findShaderConstants(params, ::Ogre::GPT_FRAGMENT_PROGRAM);
+            auto fpConstants = findShaderConstants(params, Ogre::GPT_FRAGMENT_PROGRAM);
             std::move(fpConstants.begin(), fpConstants.end(), std::inserter(constants, constants.begin()));
         }
 
         if(pass->hasGeometryProgram())
         {
             params = pass->getGeometryProgramParameters();
-            auto gpConstants = findShaderConstants(params, ::Ogre::GPT_GEOMETRY_PROGRAM);
+            auto gpConstants = findShaderConstants(params, Ogre::GPT_GEOMETRY_PROGRAM);
             std::move(gpConstants.begin(), gpConstants.end(), std::inserter(constants, constants.begin()));
         }
 
@@ -313,14 +268,14 @@ Shading::ShaderConstantsType Shading::findMaterialConstants(::Ogre::Material& _m
 //------------------------------------------------------------------------------
 
 Shading::ShaderConstantsType Shading::findShaderConstants(
-    ::Ogre::GpuProgramParametersSharedPtr _params,
-    ::Ogre::GpuProgramType _shaderType,
+    Ogre::GpuProgramParametersSharedPtr _params,
+    Ogre::GpuProgramType _shaderType,
     bool _enableLightConstants
 )
 {
     ShaderConstantsType parameters;
 
-    ::Ogre::GpuNamedConstants constantsDefinitionMap = _params->getConstantDefinitions();
+    Ogre::GpuNamedConstants constantsDefinitionMap = _params->getConstantDefinitions();
 
     // Get only user constants
     for(const auto& cstDef : constantsDefinitionMap.map)
@@ -335,13 +290,13 @@ Shading::ShaderConstantsType Shading::findShaderConstants(
             }
         }
 
-        if(!::Ogre::StringUtil::endsWith(cstDef.first, "[0]") && !_params->findAutoConstantEntry(cstDef.first))
+        if(!Ogre::StringUtil::endsWith(cstDef.first, "[0]") && !_params->findAutoConstantEntry(cstDef.first))
         {
             ConstantValueType constantValue;
             bool found = false;
             if(cstDef.second.isDouble())
             {
-                for(size_t i = 0 ; i < cstDef.second.elementSize ; ++i)
+                for(std::size_t i = 0 ; i < cstDef.second.elementSize ; ++i)
                 {
                     constantValue.d[i] = _params->getDoubleConstantList()[cstDef.second.physicalIndex + i];
                 }
@@ -350,7 +305,7 @@ Shading::ShaderConstantsType Shading::findShaderConstants(
             }
             else if(cstDef.second.isFloat())
             {
-                for(size_t i = 0 ; i < cstDef.second.elementSize ; ++i)
+                for(std::size_t i = 0 ; i < cstDef.second.elementSize ; ++i)
                 {
                     constantValue.f[i] = _params->getFloatConstantList()[cstDef.second.physicalIndex + i];
                 }
@@ -359,7 +314,7 @@ Shading::ShaderConstantsType Shading::findShaderConstants(
             }
             else if(cstDef.second.isInt())
             {
-                for(size_t i = 0 ; i < cstDef.second.elementSize ; ++i)
+                for(std::size_t i = 0 ; i < cstDef.second.elementSize ; ++i)
                 {
                     constantValue.i[i] = _params->getIntConstantList()[cstDef.second.physicalIndex + i];
                 }
@@ -386,13 +341,13 @@ Shading::ShaderConstantsType Shading::findShaderConstants(
 
 //-----------------------------------------------------------------------------
 
-data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantType _type, ConstantValueType _value)
+data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantType _type, ConstantValueType _value)
 {
     data::Object::sptr object;
 
     switch(_type)
     {
-        case ::Ogre::GpuConstantType::GCT_FLOAT1:
+        case Ogre::GpuConstantType::GCT_FLOAT1:
         {
             auto newObj = data::Float::New();
             newObj->setValue(_value.f[0]);
@@ -400,13 +355,13 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_FLOAT2:
+        case Ogre::GpuConstantType::GCT_FLOAT2:
         {
             data::Array::sptr arrayObject = data::Array::New();
 
             arrayObject->resize({2}, core::tools::Type::s_FLOAT);
 
-            const auto dumpLock = arrayObject->lock();
+            const auto dumpLock = arrayObject->dump_lock();
 
             arrayObject->at<float>(0) = _value.f[0];
             arrayObject->at<float>(1) = _value.f[1];
@@ -415,13 +370,13 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_FLOAT3:
+        case Ogre::GpuConstantType::GCT_FLOAT3:
         {
             data::Array::sptr arrayObject = data::Array::New();
 
             arrayObject->resize({3}, core::tools::Type::s_FLOAT);
 
-            const auto dumpLock = arrayObject->lock();
+            const auto dumpLock = arrayObject->dump_lock();
 
             arrayObject->at<float>(0) = _value.f[0];
             arrayObject->at<float>(1) = _value.f[1];
@@ -431,7 +386,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_FLOAT4:
+        case Ogre::GpuConstantType::GCT_FLOAT4:
         {
             auto newObj = data::Color::New();
             newObj->setRGBA(_value.f[0], _value.f[1], _value.f[2], _value.f[3]);
@@ -439,11 +394,11 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_MATRIX_4X4:
+        case Ogre::GpuConstantType::GCT_MATRIX_4X4:
             object = data::Matrix4::New();
             break;
 
-        case ::Ogre::GpuConstantType::GCT_INT1:
+        case Ogre::GpuConstantType::GCT_INT1:
         {
             auto newObj = data::Integer::New();
             newObj->setValue(_value.i[0]);
@@ -451,13 +406,13 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_INT2:
+        case Ogre::GpuConstantType::GCT_INT2:
         {
             data::Array::sptr arrayObject = data::Array::New();
 
             arrayObject->resize({2}, core::tools::Type::s_INT32);
 
-            const auto dumpLock = arrayObject->lock();
+            const auto dumpLock = arrayObject->dump_lock();
 
             arrayObject->at<std::uint32_t>(0) = static_cast<std::uint32_t>(_value.i[0]);
             arrayObject->at<std::uint32_t>(1) = static_cast<std::uint32_t>(_value.i[1]);
@@ -466,13 +421,13 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_INT3:
+        case Ogre::GpuConstantType::GCT_INT3:
         {
             data::Array::sptr arrayObject = data::Array::New();
 
             arrayObject->resize({3}, core::tools::Type::s_INT32);
 
-            const auto dumpLock = arrayObject->lock();
+            const auto dumpLock = arrayObject->dump_lock();
 
             arrayObject->at<std::uint32_t>(0) = static_cast<std::uint32_t>(_value.i[0]);
             arrayObject->at<std::uint32_t>(1) = static_cast<std::uint32_t>(_value.i[1]);
@@ -482,13 +437,13 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_INT4:
+        case Ogre::GpuConstantType::GCT_INT4:
         {
             data::Array::sptr arrayObject = data::Array::New();
 
             arrayObject->resize({4}, core::tools::Type::s_INT32);
 
-            const auto dumpLock = arrayObject->lock();
+            const auto dumpLock = arrayObject->dump_lock();
 
             arrayObject->at<std::uint32_t>(0) = static_cast<std::uint32_t>(_value.i[0]);
             arrayObject->at<std::uint32_t>(1) = static_cast<std::uint32_t>(_value.i[1]);
@@ -499,7 +454,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_DOUBLE1:
+        case Ogre::GpuConstantType::GCT_DOUBLE1:
         {
             auto newObj = data::Float::New();
             newObj->setValue(static_cast<float>(_value.d[0]));
@@ -507,13 +462,13 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_DOUBLE2:
+        case Ogre::GpuConstantType::GCT_DOUBLE2:
         {
             data::Array::sptr arrayObject = data::Array::New();
 
             arrayObject->resize({2}, core::tools::Type::s_DOUBLE);
 
-            const auto dumpLock = arrayObject->lock();
+            const auto dumpLock = arrayObject->dump_lock();
 
             arrayObject->at<double>(0) = _value.d[0];
             arrayObject->at<double>(1) = _value.d[1];
@@ -522,13 +477,13 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_DOUBLE3:
+        case Ogre::GpuConstantType::GCT_DOUBLE3:
         {
             data::Array::sptr arrayObject = data::Array::New();
 
             arrayObject->resize({3}, core::tools::Type::s_DOUBLE);
 
-            const auto dumpLock = arrayObject->lock();
+            const auto dumpLock = arrayObject->dump_lock();
 
             arrayObject->at<double>(0) = _value.d[0];
             arrayObject->at<double>(1) = _value.d[1];
@@ -538,13 +493,13 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_DOUBLE4:
+        case Ogre::GpuConstantType::GCT_DOUBLE4:
         {
             data::Array::sptr arrayObject = data::Array::New();
 
             arrayObject->resize({4}, core::tools::Type::s_DOUBLE);
 
-            const auto dumpLock = arrayObject->lock();
+            const auto dumpLock = arrayObject->dump_lock();
 
             arrayObject->at<double>(0) = _value.d[0];
             arrayObject->at<double>(1) = _value.d[1];
@@ -555,7 +510,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
             break;
         }
 
-        case ::Ogre::GpuConstantType::GCT_MATRIX_DOUBLE_4X4:
+        case Ogre::GpuConstantType::GCT_MATRIX_DOUBLE_4X4:
             object = data::Matrix4::New();
             break;
 
@@ -613,31 +568,31 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
 
 // ----------------------------------------------------------------------------
 
-::Ogre::GpuProgramPtr Shading::createProgramFrom(
+Ogre::GpuProgramPtr Shading::createProgramFrom(
     const std::string& _name,
     const std::string& _sourceFileName,
     const GpuProgramParametersType& _parameters,
-    ::Ogre::GpuProgramType _shaderType,
+    Ogre::GpuProgramType _shaderType,
     const std::string& _baseName
 )
 {
-    auto& mgr = ::Ogre::HighLevelGpuProgramManager::getSingleton();
+    auto& mgr = Ogre::HighLevelGpuProgramManager::getSingleton();
 
     auto resource = mgr.getResourceByName(_name, RESOURCE_GROUP);
     if(resource)
     {
-        return ::Ogre::dynamic_pointer_cast< ::Ogre::GpuProgram>(resource);
+        return Ogre::dynamic_pointer_cast<Ogre::GpuProgram>(resource);
     }
 
     // Create shader object
-    ::Ogre::HighLevelGpuProgramPtr newProgram;
+    Ogre::HighLevelGpuProgramPtr newProgram;
     newProgram = mgr.createProgram(_name, RESOURCE_GROUP, "glsl", _shaderType);
 
     newProgram->setSourceFile(_sourceFileName);
 
-    auto srcResource                   = mgr.getResourceByName(_baseName, RESOURCE_GROUP);
-    auto srcProgram                    = ::Ogre::dynamic_pointer_cast< ::Ogre::GpuProgram>(srcResource);
-    ::Ogre::String preprocessorDefines = srcProgram->getParameter("preprocessor_defines");
+    auto srcResource                 = mgr.getResourceByName(_baseName, RESOURCE_GROUP);
+    auto srcProgram                  = Ogre::dynamic_pointer_cast<Ogre::GpuProgram>(srcResource);
+    Ogre::String preprocessorDefines = srcProgram->getParameter("preprocessor_defines");
 
     for(const auto& params : _parameters)
     {
@@ -654,12 +609,12 @@ data::Object::sptr Shading::createObjectFromShaderParameter(::Ogre::GpuConstantT
     newProgram->setParameter("preprocessor_defines", preprocessorDefines);
 
     // Copy parameters from the source program
-    const ::Ogre::GpuProgramParametersSharedPtr& baseParams = srcProgram->getDefaultParameters();
-    const ::Ogre::GpuProgramParametersSharedPtr& params     = newProgram->getDefaultParameters();
+    const Ogre::GpuProgramParametersSharedPtr& baseParams = srcProgram->getDefaultParameters();
+    const Ogre::GpuProgramParametersSharedPtr& params     = newProgram->getDefaultParameters();
     params->copyMatchingNamedConstantsFrom(*baseParams);
 
     newProgram->load();
-    return ::Ogre::GpuProgramPtr(newProgram);
+    return Ogre::GpuProgramPtr(newProgram);
 }
 
 //-----------------------------------------------------------------------------
