@@ -27,7 +27,7 @@ namespace sight::module::viz::scene3d::adaptor
 
 using namespace core::runtime::utils;
 
-SIGHT_REGISTER_PLUGIN("::sight::module::viz::scene3d::adaptor::Plugin");
+SIGHT_REGISTER_PLUGIN("sight::module::viz::scene3d::adaptor::Plugin");
 
 Plugin::~Plugin() noexcept
 {
