@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2021 IRCAD France
+ * Copyright (C) 2018-2022 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,7 +25,7 @@
 #include <core/com/Slots.hxx>
 
 #include <data/Boolean.hpp>
-#include <data/fieldHelper/Image.hpp>
+#include <data/helper/MedicalImage.hpp>
 #include <data/helper/Vector.hpp>
 #include <data/Image.hpp>
 #include <data/Material.hpp>
@@ -60,39 +60,39 @@ static constexpr std::uint8_t s_DISTANCE_RQ_GROUP_ID = sight::viz::scene3d::comp
 
 //------------------------------------------------------------------------------
 
-::Ogre::ColourValue SImageMultiDistances::generateColor(core::tools::fwID::IDType _id)
+Ogre::ColourValue SImageMultiDistances::generateColor(core::tools::fwID::IDType _id)
 {
     switch(std::hash<std::string>()(_id) % 7)
     {
         case 0:
-            return ::Ogre::ColourValue(63 / 255.0f, 105 / 255.0f, 170 / 255.0f);
+            return Ogre::ColourValue(63 / 255.0f, 105 / 255.0f, 170 / 255.0f);
 
         case 1:
-            return ::Ogre::ColourValue(249 / 255.0f, 103 / 255.0f, 20 / 255.0f);
+            return Ogre::ColourValue(249 / 255.0f, 103 / 255.0f, 20 / 255.0f);
 
         case 2:
-            return ::Ogre::ColourValue(236 / 255.0f, 219 / 255.0f, 84 / 255.0f);
+            return Ogre::ColourValue(236 / 255.0f, 219 / 255.0f, 84 / 255.0f);
 
         case 3:
-            return ::Ogre::ColourValue(233 / 255.0f, 75 / 255.0f, 60 / 255.0f);
+            return Ogre::ColourValue(233 / 255.0f, 75 / 255.0f, 60 / 255.0f);
 
         case 4:
-            return ::Ogre::ColourValue(121 / 255.0f, 199 / 255.0f, 83 / 255.0f);
+            return Ogre::ColourValue(121 / 255.0f, 199 / 255.0f, 83 / 255.0f);
 
         case 5:
-            return ::Ogre::ColourValue(149 / 255.0f, 222 / 255.0f, 227 / 255.0f);
+            return Ogre::ColourValue(149 / 255.0f, 222 / 255.0f, 227 / 255.0f);
 
         default:
-            return ::Ogre::ColourValue(29 / 255.0f, 45 / 255.0f, 168 / 255.0f);
+            return Ogre::ColourValue(29 / 255.0f, 45 / 255.0f, 168 / 255.0f);
     }
 }
 
 //------------------------------------------------------------------------------
 
-::Ogre::Vector3 SImageMultiDistances::getCamDirection(const ::Ogre::Camera* const _cam)
+Ogre::Vector3 SImageMultiDistances::getCamDirection(const Ogre::Camera* const _cam)
 {
-    const ::Ogre::Matrix4 view = _cam->getViewMatrix();
-    ::Ogre::Vector3 direction(view[2][0], view[2][1], view[2][2]);
+    const Ogre::Matrix4 view = _cam->getViewMatrix();
+    Ogre::Vector3 direction(view[2][0], view[2][1], view[2][2]);
     direction.normalise();
     return -direction;
 }
@@ -100,18 +100,18 @@ static constexpr std::uint8_t s_DISTANCE_RQ_GROUP_ID = sight::viz::scene3d::comp
 //------------------------------------------------------------------------------
 
 void SImageMultiDistances::generateDashedLine(
-    ::Ogre::ManualObject* const _object,
-    const ::Ogre::Vector3& _begin,
-    const ::Ogre::Vector3& _end,
+    Ogre::ManualObject* const _object,
+    const Ogre::Vector3& _begin,
+    const Ogre::Vector3& _end,
     float _thickness
 )
 {
-    const ::Ogre::Vector3 dashedLineDir = (_end - _begin);
-    const float len                     = dashedLineDir.length();
-    ::Ogre::Vector3 dashedLineDirN      = (_end - _begin);
+    const Ogre::Vector3 dashedLineDir = (_end - _begin);
+    const float len                   = dashedLineDir.length();
+    Ogre::Vector3 dashedLineDirN      = (_end - _begin);
     dashedLineDirN.normalise();
 
-    ::Ogre::Vector3 dashedLinePos = _begin;
+    Ogre::Vector3 dashedLinePos = _begin;
     for(float i = 0.f ; i + _thickness * 1.5 <= len ; i += _thickness * 2)
     {
         _object->position(dashedLinePos);
@@ -125,7 +125,7 @@ void SImageMultiDistances::generateDashedLine(
 
 //------------------------------------------------------------------------------
 
-std::string SImageMultiDistances::getLength(const ::Ogre::Vector3& _begin, const ::Ogre::Vector3& _end)
+std::string SImageMultiDistances::getLength(const Ogre::Vector3& _begin, const Ogre::Vector3& _end)
 {
     const int length = static_cast<int>(std::round((_end - _begin).length()));
     return std::to_string(length) + "mm";
@@ -156,7 +156,7 @@ void SImageMultiDistances::configuring()
     const ConfigType config    = srvconfig.get_child("config.<xmlattr>");
 
     m_fontSource           = config.get(s_FONT_SOURCE_CONFIG, m_fontSource);
-    m_fontSize             = config.get<size_t>(s_FONT_SIZE_CONFIG, m_fontSize);
+    m_fontSize             = config.get<std::size_t>(s_FONT_SIZE_CONFIG, m_fontSize);
     m_distanceSphereRadius = config.get<float>(s_RADIUS_CONFIG, m_distanceSphereRadius);
     m_interactive          = config.get<bool>(s_INTERACTIVE_CONFIG, m_interactive);
     m_priority             = config.get<int>(s_PRIORITY_CONFIG, m_priority);
@@ -197,7 +197,7 @@ void SImageMultiDistances::starting()
     const sight::viz::scene3d::Layer::sptr layer = this->getLayer();
 
     m_sphereMaterialName     = this->getID() + "_sphereMaterialName";
-    m_lineMaterialName       = this->getID() + "_lineMaterialNamel";
+    m_lineMaterialName       = this->getID() + "_lineMaterialName";
     m_dashedLineMaterialName = this->getID() + "_dashedLineMaterialName";
 
     // Create materials from our wrapper.
@@ -223,25 +223,25 @@ void SImageMultiDistances::starting()
     m_dashedLineMaterial->updateShadingMode(data::Material::AMBIENT, layer->getLightsNumber(), false, false);
 
     // Retrive the ogre material to change the depth check.
-    const ::Ogre::MaterialPtr ogreSphereMaterial = ::Ogre::MaterialManager::getSingleton().getByName(
+    const Ogre::MaterialPtr ogreSphereMaterial = Ogre::MaterialManager::getSingleton().getByName(
         m_sphereMaterialName,
         sight::viz::scene3d::RESOURCE_GROUP
     );
     SIGHT_ASSERT("'" + m_sphereMaterialName + "' does not exist.", ogreSphereMaterial);
-    const ::Ogre::Technique* const sphereTech = ogreSphereMaterial->getTechnique(0);
-    SIGHT_ASSERT("No techique found", sphereTech);
-    ::Ogre::Pass* const spherePass = sphereTech->getPass(0);
+    const Ogre::Technique* const sphereTech = ogreSphereMaterial->getTechnique(0);
+    SIGHT_ASSERT("No technique found", sphereTech);
+    Ogre::Pass* const spherePass = sphereTech->getPass(0);
     SIGHT_ASSERT("No pass found", spherePass);
     spherePass->setDepthCheckEnabled(false);
 
-    const ::Ogre::MaterialPtr ogreDashedLineMaterial = ::Ogre::MaterialManager::getSingleton().getByName(
+    const Ogre::MaterialPtr ogreDashedLineMaterial = Ogre::MaterialManager::getSingleton().getByName(
         m_dashedLineMaterialName,
         sight::viz::scene3d::RESOURCE_GROUP
     );
     SIGHT_ASSERT("'" + m_dashedLineMaterialName + "' does not exist.", ogreDashedLineMaterial);
-    const ::Ogre::Technique* const dashedTech = ogreDashedLineMaterial->getTechnique(0);
-    SIGHT_ASSERT("No techique found", dashedTech);
-    ::Ogre::Pass* const dashedPass = dashedTech->getPass(0);
+    const Ogre::Technique* const dashedTech = ogreDashedLineMaterial->getTechnique(0);
+    SIGHT_ASSERT("No technique found", dashedTech);
+    Ogre::Pass* const dashedPass = dashedTech->getPass(0);
     SIGHT_ASSERT("No pass found", dashedPass);
     dashedPass->setDepthCheckEnabled(false);
 
@@ -312,9 +312,8 @@ void SImageMultiDistances::addDistances()
 
     const auto image = m_image.lock();
 
-    const data::Vector::sptr distanceField = image->getField<data::Vector>(
-        data::fieldHelper::Image::m_imageDistancesId
-    );
+    const data::Vector::sptr distanceField = data::helper::MedicalImage::getDistances(*image);
+
     if(distanceField)
     {
         for(const auto& object : *distanceField)
@@ -355,8 +354,7 @@ void SImageMultiDistances::removeDistances()
 
     const auto image = m_image.lock();
 
-    const data::Vector::csptr distanceField =
-        image->getField<data::Vector>(data::fieldHelper::Image::m_imageDistancesId);
+    const data::Vector::csptr distanceField = data::helper::MedicalImage::getDistances(*image);
 
     std::vector<core::tools::fwID::IDType> foundId;
     if(distanceField)
@@ -392,13 +390,7 @@ void SImageMultiDistances::updateVisibilityFromField()
 
     const auto image = m_image.lock();
 
-    const bool visibility = image->getField(
-        data::fieldHelper::Image::m_distanceVisibility,
-        data::Boolean::New(
-            true
-        )
-    )->value();
-    m_isVisible = visibility;
+    m_isVisible = data::helper::MedicalImage::getDistanceVisibility(*image);
 
     for(const auto& distance : m_distances)
     {
@@ -434,10 +426,10 @@ void SImageMultiDistances::setVisible(bool _visible)
 
 //------------------------------------------------------------------------------
 
-std::optional< ::Ogre::Vector3> SImageMultiDistances::getNearestPickedPosition(int _x, int _y)
+std::optional<Ogre::Vector3> SImageMultiDistances::getNearestPickedPosition(int _x, int _y)
 {
     sight::viz::scene3d::picker::IPicker picker;
-    ::Ogre::SceneManager* sm = this->getSceneManager();
+    Ogre::SceneManager* sm = this->getSceneManager();
     picker.setSceneManager(sm);
     picker.executeRaySceneQuery(_x, _y, m_queryMask);
 
@@ -450,9 +442,9 @@ std::optional< ::Ogre::Vector3> SImageMultiDistances::getNearestPickedPosition(i
         const float vpX = static_cast<float>(_x - vp->getActualLeft()) / static_cast<float>(vp->getActualWidth());
         const float vpY = static_cast<float>(_y - vp->getActualTop()) / static_cast<float>(vp->getActualHeight());
 
-        const ::Ogre::Ray ray = camera->getCameraToViewportRay(vpX, vpY);
+        const Ogre::Ray ray = camera->getCameraToViewportRay(vpX, vpY);
 
-        ::Ogre::Vector3 normal = -ray.getDirection();
+        Ogre::Vector3 normal = -ray.getDirection();
         normal.normalise();
 
         return picker.getIntersectionInWorldSpace() + normal * 0.01f;
@@ -469,27 +461,27 @@ void SImageMultiDistances::buttonPressEvent(MouseButton _button, Modifier, int _
     {
         const sight::viz::scene3d::Layer::csptr layer = this->getLayer();
 
-        ::Ogre::SceneManager* const sceneMgr = layer->getSceneManager();
+        Ogre::SceneManager* const sceneMgr = layer->getSceneManager();
 
-        const ::Ogre::Camera* const cam = layer->getDefaultCamera();
-        const auto* const vp            = cam->getViewport();
+        const Ogre::Camera* const cam = layer->getDefaultCamera();
+        const auto* const vp          = cam->getViewport();
 
         const float vpX = static_cast<float>(_x - vp->getActualLeft()) / static_cast<float>(vp->getActualWidth());
         const float vpY = static_cast<float>(_y - vp->getActualTop()) / static_cast<float>(vp->getActualHeight());
 
-        const ::Ogre::Ray ray = cam->getCameraToViewportRay(vpX, vpY);
+        const Ogre::Ray ray = cam->getCameraToViewportRay(vpX, vpY);
 
-        bool found                                 = false;
-        ::Ogre::RaySceneQuery* const raySceneQuery = sceneMgr->createRayQuery(ray, m_distanceQueryFlag);
+        bool found                               = false;
+        Ogre::RaySceneQuery* const raySceneQuery = sceneMgr->createRayQuery(ray, m_distanceQueryFlag);
         raySceneQuery->setSortByDistance(false);
         if(raySceneQuery->execute().size() != 0)
         {
-            const ::Ogre::Real scale = 1.15f;
+            const Ogre::Real scale = 1.15f;
 
-            const ::Ogre::RaySceneQueryResult& queryResult = raySceneQuery->getLastResults();
-            for(size_t qrIdx = 0 ; qrIdx < queryResult.size() && !found ; qrIdx++)
+            const Ogre::RaySceneQueryResult& queryResult = raySceneQuery->getLastResults();
+            for(std::size_t qrIdx = 0 ; qrIdx < queryResult.size() && !found ; qrIdx++)
             {
-                const ::Ogre::MovableObject* const object = queryResult[qrIdx].movable;
+                const Ogre::MovableObject* const object = queryResult[qrIdx].movable;
                 if(object->isVisible())
                 {
                     for(auto& distance : m_distances)
@@ -518,23 +510,6 @@ void SImageMultiDistances::buttonPressEvent(MouseButton _button, Modifier, int _
 
         if(found)
         {
-            // Check if something is picked to update the position of the distance.
-            std::optional< ::Ogre::Vector3> pickedPos = this->getNearestPickedPosition(_x, _y);
-            if(pickedPos.has_value())
-            {
-                if(m_pickedData.m_first)
-                {
-                    const ::Ogre::Vector3 secondPos = m_pickedData.m_data->m_node2->getPosition();
-                    this->updateDistance(m_pickedData.m_data, pickedPos.value(), secondPos);
-                }
-                else
-                {
-                    const ::Ogre::Vector3 firstPos = m_pickedData.m_data->m_node1->getPosition();
-                    this->updateDistance(m_pickedData.m_data, firstPos, pickedPos.value());
-                }
-            }
-
-            this->requestRender();
             this->getLayer()->cancelFurtherInteraction();
         }
     }
@@ -546,33 +521,43 @@ void SImageMultiDistances::mouseMoveEvent(MouseButton, Modifier, int _x, int _y,
 {
     if(m_pickedData.m_data != nullptr)
     {
-        ::Ogre::Vector3 newPos;
-
         // Discard the current distance to launch the ray over the scene without picking this one.
         m_pickedData.m_data->m_sphere1->setQueryFlags(0x0);
         m_pickedData.m_data->m_sphere2->setQueryFlags(0x0);
 
-        // Check if something is picked.
-        std::optional< ::Ogre::Vector3> pickedPos = this->getNearestPickedPosition(_x, _y);
-        if(pickedPos.has_value())
+        const auto layer              = this->getLayer();
+        const Ogre::Camera* const cam = layer->getDefaultCamera();
+        SIGHT_ASSERT("No camera found", cam);
+
+        bool moveInCameraPlane = true;
+
+        Ogre::Vector3 newPos;
+        if(cam->getProjectionType() == Ogre::ProjectionType::PT_PERSPECTIVE)
         {
-            newPos = pickedPos.value();
+            // If something is picked, we will snap the landmark to it
+            std::optional<Ogre::Vector3> pickedPos = this->getNearestPickedPosition(_x, _y);
+            if(pickedPos.has_value())
+            {
+                newPos            = pickedPos.value();
+                moveInCameraPlane = false;
+            }
         }
+
         // Else we move the distance along a plane.
-        else
+        if(moveInCameraPlane)
         {
             const sight::viz::scene3d::Layer::sptr layer = this->getLayer();
 
-            const ::Ogre::Camera* const cam = layer->getDefaultCamera();
-            const auto* const vp            = cam->getViewport();
+            const Ogre::Camera* const cam = layer->getDefaultCamera();
+            const auto* const vp          = cam->getViewport();
 
             const float vpX = static_cast<float>(_x - vp->getActualLeft()) / static_cast<float>(vp->getActualWidth());
             const float vpY = static_cast<float>(_y - vp->getActualTop()) / static_cast<float>(vp->getActualHeight());
 
-            const ::Ogre::Ray ray           = cam->getCameraToViewportRay(vpX, vpY);
-            const ::Ogre::Vector3 direction = this->getCamDirection(cam);
+            const Ogre::Ray ray           = cam->getCameraToViewportRay(vpX, vpY);
+            const Ogre::Vector3 direction = this->getCamDirection(cam);
 
-            ::Ogre::Vector3 position;
+            Ogre::Vector3 position;
             if(m_pickedData.m_first)
             {
                 position = m_pickedData.m_data->m_node1->getPosition();
@@ -582,9 +567,9 @@ void SImageMultiDistances::mouseMoveEvent(MouseButton, Modifier, int _x, int _y,
                 position = m_pickedData.m_data->m_node2->getPosition();
             }
 
-            const ::Ogre::Plane plane(direction, position);
+            const Ogre::Plane plane(direction, position);
 
-            const std::pair<bool, ::Ogre::Real> hit = ::Ogre::Math::intersects(ray, plane);
+            const std::pair<bool, Ogre::Real> hit = Ogre::Math::intersects(ray, plane);
 
             if(!hit.first)
             {
@@ -601,12 +586,12 @@ void SImageMultiDistances::mouseMoveEvent(MouseButton, Modifier, int _x, int _y,
 
         if(m_pickedData.m_first)
         {
-            const ::Ogre::Vector3 secondPos = m_pickedData.m_data->m_node2->getPosition();
+            const Ogre::Vector3 secondPos = m_pickedData.m_data->m_node2->getPosition();
             this->updateDistance(m_pickedData.m_data, newPos, secondPos);
         }
         else
         {
-            const ::Ogre::Vector3 firstPos = m_pickedData.m_data->m_node1->getPosition();
+            const Ogre::Vector3 firstPos = m_pickedData.m_data->m_node1->getPosition();
             this->updateDistance(m_pickedData.m_data, firstPos, newPos);
         }
 
@@ -621,7 +606,7 @@ void SImageMultiDistances::buttonReleaseEvent(MouseButton, Modifier, int, int)
 {
     if(m_pickedData.m_data != nullptr)
     {
-        const ::Ogre::Real scale = 1.f;
+        const Ogre::Real scale = 1.f;
         m_pickedData.m_data->m_node1->setScale(scale, scale, scale);
         m_pickedData.m_data->m_node2->setScale(scale, scale, scale);
         m_pickedData = {nullptr, true};
@@ -637,24 +622,24 @@ void SImageMultiDistances::createDistance(data::PointList::sptr _pl)
     const core::tools::fwID::IDType id = _pl->getID();
     SIGHT_ASSERT("The distance already exist", m_distances.find(id) == m_distances.end());
 
-    ::Ogre::SceneManager* const sceneMgr = this->getSceneManager();
-    ::Ogre::SceneNode* const rootNode    = sceneMgr->getRootSceneNode();
+    Ogre::SceneManager* const sceneMgr = this->getSceneManager();
+    Ogre::SceneNode* const rootNode    = sceneMgr->getRootSceneNode();
 
     // Retrieve data used to create Ogre resources.
-    const ::Ogre::ColourValue colour = SImageMultiDistances::generateColor(id);
+    const Ogre::ColourValue colour = SImageMultiDistances::generateColor(id);
 
     const std::array<double, 3> front = _pl->getPoints().front()->getCoord();
     const std::array<double, 3> back  = _pl->getPoints().back()->getCoord();
 
-    const ::Ogre::Vector3 begin(static_cast<float>(front[0]),
-                                static_cast<float>(front[1]),
-                                static_cast<float>(front[2]));
-    const ::Ogre::Vector3 end(static_cast<float>(back[0]),
-                              static_cast<float>(back[1]),
-                              static_cast<float>(back[2]));
+    const Ogre::Vector3 begin(static_cast<float>(front[0]),
+                              static_cast<float>(front[1]),
+                              static_cast<float>(front[2]));
+    const Ogre::Vector3 end(static_cast<float>(back[0]),
+                            static_cast<float>(back[1]),
+                            static_cast<float>(back[2]));
 
     // First sphere.
-    ::Ogre::ManualObject* const sphere1 = sceneMgr->createManualObject(this->getID() + "_sphere1_" + id);
+    Ogre::ManualObject* const sphere1 = sceneMgr->createManualObject(this->getID() + "_sphere1_" + id);
     sight::viz::scene3d::helper::ManualObject::createSphere(
         sphere1,
         m_sphereMaterialName,
@@ -665,12 +650,12 @@ void SImageMultiDistances::createDistance(data::PointList::sptr _pl)
     // Render this sphere over all others objects.
     sphere1->setRenderQueueGroup(s_DISTANCE_RQ_GROUP_ID);
     SIGHT_ASSERT("Can't create the first entity", sphere1);
-    ::Ogre::SceneNode* const node1 = rootNode->createChildSceneNode(this->getID() + "_node1_" + id, begin);
+    Ogre::SceneNode* const node1 = rootNode->createChildSceneNode(this->getID() + "_node1_" + id, begin);
     SIGHT_ASSERT("Can't create the first node", node1);
     node1->attachObject(sphere1);
 
     // Second sphere.
-    ::Ogre::ManualObject* const sphere2 = sceneMgr->createManualObject(this->getID() + "_sphere2_" + id);
+    Ogre::ManualObject* const sphere2 = sceneMgr->createManualObject(this->getID() + "_sphere2_" + id);
     sight::viz::scene3d::helper::ManualObject::createSphere(
         sphere2,
         m_sphereMaterialName,
@@ -681,14 +666,14 @@ void SImageMultiDistances::createDistance(data::PointList::sptr _pl)
     // Render this sphere over all others objects.
     sphere2->setRenderQueueGroup(s_DISTANCE_RQ_GROUP_ID);
     SIGHT_ASSERT("Can't create the second entity", sphere2);
-    ::Ogre::SceneNode* const node2 = rootNode->createChildSceneNode(this->getID() + "_node2_" + id, end);
+    Ogre::SceneNode* const node2 = rootNode->createChildSceneNode(this->getID() + "_node2_" + id, end);
     SIGHT_ASSERT("Can't create the second node", node2);
     node2->attachObject(sphere2);
 
     // Line.
-    ::Ogre::ManualObject* const line = sceneMgr->createManualObject(this->getID() + "_line_" + id);
+    Ogre::ManualObject* const line = sceneMgr->createManualObject(this->getID() + "_line_" + id);
     SIGHT_ASSERT("Can't create the line", line);
-    line->begin(m_lineMaterialName, ::Ogre::RenderOperation::OT_LINE_LIST, sight::viz::scene3d::RESOURCE_GROUP);
+    line->begin(m_lineMaterialName, Ogre::RenderOperation::OT_LINE_LIST, sight::viz::scene3d::RESOURCE_GROUP);
     line->colour(colour);
     line->position(begin);
     line->position(end);
@@ -697,11 +682,11 @@ void SImageMultiDistances::createDistance(data::PointList::sptr _pl)
     rootNode->attachObject(line);
 
     // Dashed line.
-    ::Ogre::ManualObject* const dashedLine = sceneMgr->createManualObject(this->getID() + "_dashedLine_" + id);
+    Ogre::ManualObject* const dashedLine = sceneMgr->createManualObject(this->getID() + "_dashedLine_" + id);
     SIGHT_ASSERT("Can't create the dashed line", dashedLine);
     dashedLine->begin(
         m_dashedLineMaterialName,
-        ::Ogre::RenderOperation::OT_LINE_LIST,
+        Ogre::RenderOperation::OT_LINE_LIST,
         sight::viz::scene3d::RESOURCE_GROUP
     );
     dashedLine->colour(colour);
@@ -717,10 +702,10 @@ void SImageMultiDistances::createDistance(data::PointList::sptr _pl)
     rootNode->attachObject(dashedLine);
 
     // Label.
-    const sight::viz::scene3d::Layer::sptr layer  = this->getLayer();
-    ::Ogre::OverlayContainer* const textContainer = layer->getOverlayTextPanel();
-    ::Ogre::Camera* const cam                     = layer->getDefaultCamera();
-    const float dpi                               =
+    const sight::viz::scene3d::Layer::sptr layer = this->getLayer();
+    Ogre::OverlayContainer* const textContainer  = layer->getOverlayTextPanel();
+    Ogre::Camera* const cam                      = layer->getDefaultCamera();
+    const float dpi                              =
         this->getRenderService()->getInteractorManager()->getLogicalDotsPerInch();
     sight::viz::scene3d::Text* label = sight::viz::scene3d::Text::New(
         this->getID() + "_label_" + id,
@@ -735,7 +720,7 @@ void SImageMultiDistances::createDistance(data::PointList::sptr _pl)
     label->setText(length);
     label->setTextColor(colour);
     label->setQueryFlags(0x0);
-    ::Ogre::SceneNode* const labelNode =
+    Ogre::SceneNode* const labelNode =
         rootNode->createChildSceneNode(this->getID() + "_labelNode_" + id, end);
     SIGHT_ASSERT("Can't create the label node", labelNode);
     labelNode->attachObject(label);
@@ -756,8 +741,8 @@ void SImageMultiDistances::createDistance(data::PointList::sptr _pl)
 
 void SImageMultiDistances::updateDistance(
     const DistanceData* const _data,
-    ::Ogre::Vector3 _begin,
-    ::Ogre::Vector3 _end
+    Ogre::Vector3 _begin,
+    Ogre::Vector3 _end
 )
 {
     SIGHT_ASSERT("Distance can't be null", _data);
@@ -767,7 +752,7 @@ void SImageMultiDistances::updateDistance(
     _data->m_node2->setPosition(_end);
 
     // Update the line.
-    ::Ogre::ManualObject* const line = _data->m_line;
+    Ogre::ManualObject* const line = _data->m_line;
     line->beginUpdate(0);
     line->position(_begin);
     line->position(_end);
@@ -779,7 +764,7 @@ void SImageMultiDistances::updateDistance(
     _data->m_labelNode->setPosition(_end);
 
     // Update the dashed line
-    ::Ogre::ManualObject* const dashedLine = _data->m_dashedLine;
+    Ogre::ManualObject* const dashedLine = _data->m_dashedLine;
     dashedLine->beginUpdate(0);
     SImageMultiDistances::generateDashedLine(dashedLine, _begin, _end, m_distanceSphereRadius);
 
@@ -806,8 +791,8 @@ void SImageMultiDistances::destroyDistance(core::tools::fwID::IDType _id)
     SIGHT_ASSERT("The distance is not found", it != m_distances.end());
 
     // Destroy Ogre resource.
-    const DistanceData distanceData      = it->second;
-    ::Ogre::SceneManager* const sceneMgr = this->getSceneManager();
+    const DistanceData distanceData    = it->second;
+    Ogre::SceneManager* const sceneMgr = this->getSceneManager();
 
     sceneMgr->destroySceneNode(distanceData.m_node1);
     sceneMgr->destroyManualObject(distanceData.m_sphere1);
