@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2022 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -74,7 +74,7 @@ SMesh::~SMesh() noexcept
 {
     if(m_entity)
     {
-        ::Ogre::SceneManager* sceneMgr = this->getSceneManager();
+        Ogre::SceneManager* sceneMgr = this->getSceneManager();
         sceneMgr->destroyEntity(m_entity);
     }
 }
@@ -152,11 +152,11 @@ void SMesh::starting()
         this->setTransformId(this->getID() + "_TF");
     }
 
-    m_meshGeometry = ::std::make_shared<sight::viz::scene3d::Mesh>(this->getID());
+    m_meshGeometry = std::make_shared<sight::viz::scene3d::Mesh>(this->getID());
     m_meshGeometry->setDynamic(m_isDynamic);
     m_meshGeometry->setDynamicVertices(m_isDynamicVertices);
 
-    // We have to create a new material adaptor only if this adaptor is instanciated by a reconstruction adaptor
+    // We have to create a new material adaptor only if this adaptor is instantiated by a reconstruction adaptor
     // or if no material adaptor uid has been configured
     m_useNewMaterialAdaptor = m_isReconstructionManaged || m_materialName.empty();
 
@@ -192,11 +192,11 @@ void SMesh::starting()
 service::IService::KeyConnectionsMap SMesh::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_MESH_INOUT, data::Mesh::s_VERTEX_MODIFIED_SIG, s_MODIFY_VERTICES_SLOT);
-    connections.push(s_MESH_INOUT, data::Mesh::s_POINT_COLORS_MODIFIED_SIG, s_MODIFY_COLORS_SLOT);
-    connections.push(s_MESH_INOUT, data::Mesh::s_CELL_COLORS_MODIFIED_SIG, s_MODIFY_COLORS_SLOT);
-    connections.push(s_MESH_INOUT, data::Mesh::s_POINT_TEX_COORDS_MODIFIED_SIG, s_MODIFY_POINT_TEX_COORDS_SLOT);
-    connections.push(s_MESH_INOUT, data::Mesh::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_MESH_IN, data::Mesh::s_VERTEX_MODIFIED_SIG, s_MODIFY_VERTICES_SLOT);
+    connections.push(s_MESH_IN, data::Mesh::s_POINT_COLORS_MODIFIED_SIG, s_MODIFY_COLORS_SLOT);
+    connections.push(s_MESH_IN, data::Mesh::s_CELL_COLORS_MODIFIED_SIG, s_MODIFY_COLORS_SLOT);
+    connections.push(s_MESH_IN, data::Mesh::s_POINT_TEX_COORDS_MODIFIED_SIG, s_MODIFY_POINT_TEX_COORDS_SLOT);
+    connections.push(s_MESH_IN, data::Mesh::s_MODIFIED_SIG, s_UPDATE_SLOT);
     return connections;
 }
 
@@ -213,8 +213,8 @@ void SMesh::updating()
 
     if(m_meshGeometry->hasColorLayerChanged(mesh.get_shared()))
     {
-        ::Ogre::SceneManager* sceneMgr = this->getSceneManager();
-        SIGHT_ASSERT("::Ogre::SceneManager is null", sceneMgr);
+        Ogre::SceneManager* sceneMgr = this->getSceneManager();
+        SIGHT_ASSERT("Ogre::SceneManager is null", sceneMgr);
         m_meshGeometry->clearMesh(*sceneMgr);
     }
 
@@ -227,8 +227,8 @@ void SMesh::stopping()
 {
     this->getRenderService()->makeCurrent();
 
-    ::Ogre::SceneManager* sceneMgr = this->getSceneManager();
-    SIGHT_ASSERT("::Ogre::SceneManager is null", sceneMgr);
+    Ogre::SceneManager* sceneMgr = this->getSceneManager();
+    SIGHT_ASSERT("Ogre::SceneManager is null", sceneMgr);
 
     this->unregisterServices();
 
@@ -260,12 +260,12 @@ void module::viz::scene3d::adaptor::SMesh::setVisible(bool _visible)
 
 //-----------------------------------------------------------------------------
 
-void SMesh::updateMesh(const data::Mesh::sptr& _mesh)
+void SMesh::updateMesh(data::Mesh::csptr _mesh)
 {
-    ::Ogre::SceneManager* sceneMgr = this->getSceneManager();
-    SIGHT_ASSERT("::Ogre::SceneManager is null", sceneMgr);
+    Ogre::SceneManager* sceneMgr = this->getSceneManager();
+    SIGHT_ASSERT("Ogre::SceneManager is null", sceneMgr);
 
-    const size_t uiNumVertices = _mesh->getNumberOfPoints();
+    const std::size_t uiNumVertices = _mesh->numPoints();
     if(uiNumVertices == 0)
     {
         SIGHT_DEBUG("Empty mesh");
@@ -328,8 +328,7 @@ void SMesh::updateMesh(const data::Mesh::sptr& _mesh)
     auto r2vbRenderables = m_meshGeometry->updateR2VB(
         _mesh,
         *sceneMgr,
-        m_materialAdaptor->getMaterialName(),
-        m_materialAdaptor->hasDiffuseTexture()
+        m_materialAdaptor->getMaterialName()
     );
     for(auto renderable : r2vbRenderables.second)
     {
@@ -385,12 +384,12 @@ void SMesh::updateMesh(const data::Mesh::sptr& _mesh)
 //------------------------------------------------------------------------------
 
 adaptor::SMaterial::sptr SMesh::createMaterialService(
-    const data::Mesh::sptr& _mesh,
+    data::Mesh::csptr _mesh,
     const std::string& _materialSuffix
 )
 {
     auto materialAdaptor = this->registerService<module::viz::scene3d::adaptor::SMaterial>(
-        "::sight::module::viz::scene3d::adaptor::SMaterial"
+        "sight::module::viz::scene3d::adaptor::SMaterial"
     );
     materialAdaptor->setInOut(m_material, "material", true);
 
@@ -407,7 +406,12 @@ adaptor::SMaterial::sptr SMesh::createMaterialService(
     const std::string mtlName  = meshName + "_" + materialAdaptor->getID() + _materialSuffix;
 
     materialAdaptor->setMaterialName(mtlName);
-    materialAdaptor->setTextureName(m_textureName);
+    if(_materialSuffix.empty())
+    {
+        // We know that we are in the case of a R2VB material, so no need to set the diffuse texture (no FP...)
+        materialAdaptor->setTextureName(m_textureName);
+    }
+
     materialAdaptor->setShadingMode(m_shadingMode);
 
     return materialAdaptor;
@@ -415,7 +419,7 @@ adaptor::SMaterial::sptr SMesh::createMaterialService(
 
 //------------------------------------------------------------------------------
 
-void SMesh::updateNewMaterialAdaptor(const data::Mesh::sptr& _mesh)
+void SMesh::updateNewMaterialAdaptor(data::Mesh::csptr _mesh)
 {
     if(!m_materialAdaptor)
     {
@@ -485,12 +489,11 @@ void SMesh::modifyVertices()
 
     m_meshGeometry->updateVertices(mesh.get_shared());
 
-    ::Ogre::SceneManager* const sceneMgr = this->getSceneManager();
+    Ogre::SceneManager* const sceneMgr = this->getSceneManager();
     m_meshGeometry->updateR2VB(
         mesh.get_shared(),
         *sceneMgr,
-        m_materialAdaptor->getMaterialName(),
-        m_materialAdaptor->hasDiffuseTexture()
+        m_materialAdaptor->getMaterialName()
     );
 
     // Necessary to update the bounding box in the adaptor
@@ -520,8 +523,8 @@ void SMesh::modifyPointColors()
 
     if(m_meshGeometry->hasColorLayerChanged(mesh.get_shared()))
     {
-        ::Ogre::SceneManager* sceneMgr = this->getSceneManager();
-        SIGHT_ASSERT("::Ogre::SceneManager is null", sceneMgr);
+        Ogre::SceneManager* sceneMgr = this->getSceneManager();
+        SIGHT_ASSERT("Ogre::SceneManager is null", sceneMgr);
         m_meshGeometry->clearMesh(*sceneMgr);
         this->updateMesh(mesh.get_shared());
     }
@@ -554,12 +557,12 @@ void SMesh::modifyTexCoords()
 
 //-----------------------------------------------------------------------------
 
-void SMesh::attachNode(::Ogre::MovableObject* _node)
+void SMesh::attachNode(Ogre::MovableObject* _node)
 {
-    ::Ogre::SceneNode* rootSceneNode = this->getSceneManager()->getRootSceneNode();
-    ::Ogre::SceneNode* transNode     = this->getTransformNode(rootSceneNode);
+    Ogre::SceneNode* rootSceneNode = this->getSceneManager()->getRootSceneNode();
+    Ogre::SceneNode* transNode     = this->getOrCreateTransformNode(rootSceneNode);
 
-    ::Ogre::SceneNode* node = _node->getParentSceneNode();
+    Ogre::SceneNode* node = _node->getParentSceneNode();
 
     if(node != transNode)
     {
