@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2021 IRCAD France
+ * Copyright (C) 2019-2022 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -104,8 +104,8 @@ void SNegato2DCamera::starting()
     auto interactor  = std::dynamic_pointer_cast<sight::viz::scene3d::interactor::IInteractor>(this->getSptr());
     layer->addInteractor(interactor, m_priority);
 
-    ::Ogre::Camera* const cam = this->getLayer()->getDefaultCamera();
-    cam->setProjectionType(::Ogre::ProjectionType::PT_ORTHOGRAPHIC);
+    Ogre::Camera* const cam = this->getLayer()->getDefaultCamera();
+    cam->setProjectionType(Ogre::ProjectionType::PT_ORTHOGRAPHIC);
 
     this->resetCamera();
 }
@@ -152,43 +152,113 @@ service::IService::KeyConnectionsMap SNegato2DCamera::getAutoConnections() const
 
 //-----------------------------------------------------------------------------
 
-void SNegato2DCamera::wheelEvent(Modifier, int _delta, int _x, int _y)
+void SNegato2DCamera::wheelEvent(Modifier _modifier, int _delta, int _x, int _y)
 {
     const auto layer = this->getLayer();
 
     if(IInteractor::isInLayer(_x, _y, layer, m_layerOrderDependant))
     {
-        const auto* const viewport = layer->getViewport();
-        auto* const camera         = layer->getDefaultCamera();
-        auto* const camNode        = camera->getParentNode();
+        // CTRL + wheel = Zoom in/out.
+        if(_modifier == Modifier::CONTROL)
+        {
+            const auto* const viewport = layer->getViewport();
+            auto* const camera         = layer->getDefaultCamera();
+            auto* const camNode        = camera->getParentNode();
 
-        constexpr float mouseWheelScale = 0.05f;
-        const float zoomAmount          = static_cast<float>(-_delta) * mouseWheelScale;
+            constexpr float mouseWheelScale = 0.05f;
+            const float zoomAmount          = static_cast<float>(-_delta) * mouseWheelScale;
 
-        // Compute the mouse's position in the camera's view.
-        const ::Ogre::Vector3 screenPos(static_cast< ::Ogre::Real>(_x),
-                                        static_cast< ::Ogre::Real>(_y),
-                                        ::Ogre::Real(0));
-        const auto mousePosView =
-            sight::viz::scene3d::helper::Camera::convertScreenSpaceToViewSpace(*camera, screenPos);
+            // Compute the mouse's position in the camera's view.
+            const Ogre::Vector3 screenPos(static_cast<Ogre::Real>(_x),
+                                          static_cast<Ogre::Real>(_y),
+                                          Ogre::Real(0));
+            const auto mousePosView =
+                sight::viz::scene3d::helper::Camera::convertScreenSpaceToViewSpace(*camera, screenPos);
 
-        // Zoom in.
-        const float orthoHeight    = camera->getOrthoWindowHeight();
-        const float newOrthoHeight = orthoHeight + (orthoHeight / zoomAmount);
-        const float clampedHeight  = std::max(newOrthoHeight, 1e-7f); // Make sure the height is strictly greater than 0
+            // Zoom in.
+            const float orthoHeight    = camera->getOrthoWindowHeight();
+            const float newOrthoHeight = orthoHeight + (orthoHeight / zoomAmount);
+            const float clampedHeight  = std::max(newOrthoHeight, 1e-7f); // Make sure the height is strictly greater
+                                                                          // than 0
 
-        const float vpWidth  = static_cast<float>(viewport->getActualWidth());
-        const float vpHeight = static_cast<float>(viewport->getActualHeight());
+            const float vpWidth  = static_cast<float>(viewport->getActualWidth());
+            const float vpHeight = static_cast<float>(viewport->getActualHeight());
 
-        camera->setAspectRatio(vpWidth / vpHeight);
-        camera->setOrthoWindowHeight(clampedHeight);
+            camera->setAspectRatio(vpWidth / vpHeight);
+            camera->setOrthoWindowHeight(clampedHeight);
 
-        // Compute the mouse's position in the zoomed view.
-        const auto newMousePosView =
-            sight::viz::scene3d::helper::Camera::convertScreenSpaceToViewSpace(*camera, screenPos);
+            // Compute the mouse's position in the zoomed view.
+            const auto newMousePosView =
+                sight::viz::scene3d::helper::Camera::convertScreenSpaceToViewSpace(*camera, screenPos);
 
-        // Translate the camera back to the cursor's previous position.
-        camNode->translate(mousePosView - newMousePosView);
+            // Translate the camera back to the cursor's previous position.
+            camNode->translate(mousePosView - newMousePosView);
+        }
+        // Wheel alone or other modifier -> moving along slices (SHIFT to speed-up)
+        else
+        {
+            namespace imHelper = data::helper::MedicalImage;
+
+            const auto image = m_image.lock();
+
+            // Get Index
+            const int current_index =
+                static_cast<int>(imHelper::getSliceIndex(*image, m_currentNegatoOrientation).value_or(0));
+            const int max_slice = static_cast<int>(image->getSize()[m_currentNegatoOrientation] - 1);
+
+            if(max_slice < 0)
+            {
+                // Do nothing, image doesn't have slices.
+                return;
+            }
+
+            SIGHT_ASSERT("Slice index field missing", current_index != -1);
+
+            // From: https://doc.qt.io/qt-5/qwheelevent.html#angleDelta
+            // Most mouse types work in steps of 15 degrees,
+            // in which case the delta value is a multiple of 120; i.e., 120 units * 1/8 = 15 degrees.
+
+            // Here we assume that each 120 units of delta correspond to one increment of mouse wheel
+            // So we move forward/backward of 1 slice each 120 units.
+
+            int slice_move = _delta / 120;
+
+            // Speed up SHIFT+ wheel: "scrolls" 5% of total slices at each wheel move.
+            if(_modifier == Modifier::SHIFT)
+            {
+                slice_move *= std::round(static_cast<float>(max_slice) * 5.f / 100.f);
+            }
+
+            // TODO: We may test for finer-resolution wheels and wait for another event before moving.
+
+            auto new_slice_index = current_index + slice_move;
+
+            // Limit to [0: max_slice].
+            if(new_slice_index > max_slice)
+            {
+                new_slice_index = max_slice;
+            }
+            else if(new_slice_index < 0)
+            {
+                new_slice_index = 0;
+            }
+
+            imHelper::setSliceIndex(*image, m_currentNegatoOrientation, new_slice_index);
+
+            // Get up-to-date index values.
+            const int idx[3] = {
+                static_cast<int>(imHelper::getSliceIndex(*image, imHelper::orientation_t::SAGITTAL).value_or(0)),
+                static_cast<int>(imHelper::getSliceIndex(*image, imHelper::orientation_t::FRONTAL).value_or(0)),
+                static_cast<int>(imHelper::getSliceIndex(*image, imHelper::orientation_t::AXIAL).value_or(0))
+            };
+
+            // Send signal.
+            auto sig = image->signal<data::Image::SliceIndexModifiedSignalType>(
+                data::Image::s_SLICE_INDEX_MODIFIED_SIG
+            );
+            // this->moveBack() will be automatically called due to auto-connection.
+            sig->asyncEmit(idx[2], idx[1], idx[0]);
+        }
     }
 }
 
@@ -203,12 +273,12 @@ void SNegato2DCamera::mouseMoveEvent(IInteractor::MouseButton _button, Modifier,
         auto* const camera  = layer->getDefaultCamera();
         auto* const camNode = camera->getParentNode();
 
-        const ::Ogre::Vector3 deltaScreenPos(static_cast< ::Ogre::Real>(_x - _dx),
-                                             static_cast< ::Ogre::Real>(_y - _dy),
-                                             ::Ogre::Real(0));
-        const ::Ogre::Vector3 screenPos(static_cast< ::Ogre::Real>(_x),
-                                        static_cast< ::Ogre::Real>(_y),
-                                        ::Ogre::Real(0));
+        const Ogre::Vector3 deltaScreenPos(static_cast<Ogre::Real>(_x - _dx),
+                                           static_cast<Ogre::Real>(_y - _dy),
+                                           Ogre::Real(0));
+        const Ogre::Vector3 screenPos(static_cast<Ogre::Real>(_x),
+                                      static_cast<Ogre::Real>(_y),
+                                      Ogre::Real(0));
 
         const auto previousMousePosView =
             sight::viz::scene3d::helper::Camera::convertScreenSpaceToViewSpace(*camera, deltaScreenPos);
@@ -290,12 +360,12 @@ void SNegato2DCamera::resetCamera()
     // HACK: Temporarily set the near clip distance here because the Layer doesn't handle orthographic cameras.
     camera->setNearClipDistance(1e-3f);
 
-    camNode->setPosition(::Ogre::Vector3::ZERO);
+    camNode->setPosition(Ogre::Vector3::ZERO);
     camNode->resetOrientation();
 
-    const auto origin  = image->getOrigin2();
-    const auto size    = image->getSize2();
-    const auto spacing = image->getSpacing2();
+    const auto origin  = image->getOrigin();
+    const auto size    = image->getSize();
+    const auto spacing = image->getSpacing();
 
     if(size[0] > 0 && size[1] > 0 && size[2] > 0)
     {
@@ -305,23 +375,23 @@ void SNegato2DCamera::resetCamera()
         switch(m_currentNegatoOrientation)
         {
             case Orientation::X_AXIS:
-                camNode->rotate(::Ogre::Vector3::UNIT_Y, ::Ogre::Degree(-90.f));
-                camNode->rotate(::Ogre::Vector3::UNIT_Z, ::Ogre::Degree(-90.f));
+                camNode->rotate(Ogre::Vector3::UNIT_Y, Ogre::Degree(-90.f));
+                camNode->rotate(Ogre::Vector3::UNIT_Z, Ogre::Degree(-90.f));
                 width  = static_cast<double>(size[1]) * spacing[1];
                 height = static_cast<double>(size[2]) * spacing[2];
                 ratio  = static_cast<float>(width / height);
                 break;
 
             case Orientation::Y_AXIS:
-                camNode->rotate(::Ogre::Vector3::UNIT_X, ::Ogre::Degree(90.f));
+                camNode->rotate(Ogre::Vector3::UNIT_X, Ogre::Degree(90.f));
                 width  = static_cast<double>(size[0]) * spacing[0];
                 height = static_cast<double>(size[2]) * spacing[2];
                 ratio  = static_cast<float>(width / height);
                 break;
 
             case Orientation::Z_AXIS:
-                camNode->rotate(::Ogre::Vector3::UNIT_Z, ::Ogre::Degree(180.f));
-                camNode->rotate(::Ogre::Vector3::UNIT_Y, ::Ogre::Degree(180.f));
+                camNode->rotate(Ogre::Vector3::UNIT_Z, Ogre::Degree(180.f));
+                camNode->rotate(Ogre::Vector3::UNIT_Y, Ogre::Degree(180.f));
                 height = static_cast<double>(size[0]) * spacing[0];
                 width  = static_cast<double>(size[1]) * spacing[1];
                 ratio  = static_cast<float>(width / height);
@@ -330,27 +400,27 @@ void SNegato2DCamera::resetCamera()
 
         if(vpRatio > ratio)
         {
-            const ::Ogre::Real h = static_cast< ::Ogre::Real>(height);
+            const Ogre::Real h = static_cast<Ogre::Real>(height);
             // Zoom out the camera (add 10% of the height), allow the image to not be stuck on the viewport.
             camera->setOrthoWindowHeight(h + h * 0.1f);
         }
         else
         {
-            const ::Ogre::Real w = static_cast< ::Ogre::Real>(width);
+            const Ogre::Real w = static_cast<Ogre::Real>(width);
             // Zoom out the camera (add 10% of the width), allow the image to not be stuck on the viewport.
             camera->setOrthoWindowWidth(w + w * 0.1f);
         }
 
-        const size_t orientation = static_cast<size_t>(m_currentNegatoOrientation);
-        ::Ogre::Vector3 camPos(
-            static_cast< ::Ogre::Real>(origin[0] + static_cast<double>(size[0]) * spacing[0] * 0.5),
-            static_cast< ::Ogre::Real>(origin[1] + static_cast<double>(size[1]) * spacing[1] * 0.5),
-            static_cast< ::Ogre::Real>(origin[2] + static_cast<double>(size[2]) * spacing[2] * 0.5)
+        const std::size_t orientation = static_cast<std::size_t>(m_currentNegatoOrientation);
+        Ogre::Vector3 camPos(
+            static_cast<Ogre::Real>(origin[0] + static_cast<double>(size[0]) * spacing[0] * 0.5),
+            static_cast<Ogre::Real>(origin[1] + static_cast<double>(size[1]) * spacing[1] * 0.5),
+            static_cast<Ogre::Real>(origin[2] + static_cast<double>(size[2]) * spacing[2] * 0.5)
         );
 
         camPos[orientation] =
-            static_cast< ::Ogre::Real>(origin[orientation] - static_cast<double>(size[orientation])
-                                       * spacing[orientation]);
+            static_cast<Ogre::Real>(origin[orientation] - static_cast<double>(size[orientation])
+                                    * spacing[orientation]);
         camNode->setPosition(camPos);
 
         const auto worldBoundingBox = layer->computeWorldBoundingBox();
@@ -394,7 +464,7 @@ void SNegato2DCamera::moveBack()
 
     if(worldBoundingBox.isFinite())
     {
-        const size_t orientation = static_cast<size_t>(m_currentNegatoOrientation);
+        const std::size_t orientation = static_cast<std::size_t>(m_currentNegatoOrientation);
 
         auto camPos = camNode->getPosition();
 
