@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2021 IRCAD France
+ * Copyright (C) 2018-2022 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,7 +23,6 @@
 #include "Plugin.hpp"
 
 #include <core/com/Slot.hxx>
-#include <core/thread/ActiveWorkers.hpp>
 
 #include <data/Image.hpp>
 #include <data/ImageSeries.hpp>
@@ -149,8 +148,7 @@ void Plugin::initialize()
     );
 
     // extrator/converter
-    auto extractImage         = m_appManager->addService("sight::module::data::SExtractObj", true, false);
-    auto medicaImageConverter = m_appManager->addService("sight::module::data::MedicalImageSrv", true);
+    auto extractImage = m_appManager->addService("sight::module::data::SGetImage", true, false);
 
     //editors
     auto snapshotAdp = m_appManager->addService(
@@ -433,9 +431,7 @@ void Plugin::initialize()
     *              extractor configuration
     ****************************************************************************************/
 
-    service::IService::ConfigType extractImageConfig;
-    extractImageConfig.put("inout.extract.<xmlattr>.from", "@image");
-    extractImage->configure(extractImageConfig);
+    extractImage->configure();
 
     /* **************************************************************************************
     *              editors configuration
@@ -514,15 +510,14 @@ void Plugin::initialize()
 
     imageSeriesReader->setInOut(imageSeries, "data");
     snapshotAdp->setInOut(snapshot, "image", true);
-    extractImage->setInOut(imageSeries, "source");
+    extractImage->setInput(imageSeries, "imageSeries");
     mesher50->setInput(imageSeries, "imageSeries");
     mesher80->setInput(imageSeries, "imageSeries");
 
     modelSeriesWriter->setObjectId("data", s_MODEL_SERIES_ID);
     sliderIndexEditor->setObjectId("image", s_IMAGE_ID);
     imageAdaptor->setObjectId("image", s_IMAGE_ID);
-    extractImage->setObjectId("target", s_IMAGE_ID, 0);
-    medicaImageConverter->setObjectId("image", s_IMAGE_ID);
+    extractImage->setObjectId("image", s_IMAGE_ID);
     listOrganEditor->setObjectId("modelSeries", s_MODEL_SERIES_ID);
     organMaterialEditor->setObjectId("reconstruction", s_RECONSTRUCTION_ID);
     representationEditor->setObjectId("reconstruction", s_RECONSTRUCTION_ID);
@@ -534,9 +529,8 @@ void Plugin::initialize()
     *              connect the services
     ****************************************************************************************/
 
-    auto worker         = core::thread::Worker::New();
-    auto workerRegistry = core::thread::ActiveWorkers::getDefault();
-    workerRegistry->addWorker("Tuto09", worker);
+    auto worker = core::thread::Worker::New();
+    core::thread::addWorker("Tuto09", worker);
 
     auto proxy = service::registry::Proxy::getDefault();
 
@@ -622,6 +616,8 @@ void Plugin::uninitialize() noexcept
 
     m_appManager->destroy();
     m_appManager.reset();
+
+    core::thread::removeWorker("Tuto09");
 }
 
 //------------------------------------------------------------------------------
